*! version 1.1.1  02mar2005  by Robert Jaeckle jaeckle@ifo.de
*! version 1.1.7  30jan2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.2  20jun2009  by Marc Muendler  muendler@ucsd.edu

clear
set memory 500m
set more off
capture log close

cd "$rootslct"

tempfile merge_ustan merge_sec cntrgrpbem wage_diff_2000 wage_diff_1996 chosen_1996 bef_reshape_1996 bef_reshape_2000 addlsec_1996 addlsec_2000 addlfirm addlaffl

log using "logs/mvprobit-prepare-selct-$waglvl-pt$par-af$aff.log", replace

global year 2000  /* for Swedish wage setting from 1998 to 2000 in #translog-wages.do */
global tlogyear = 2000  /* for German wage setting */
global selyear  = 1996  /* for German wage setting */

* Apply BEM cntrybemgrp definitions
capture program drop countrygrp_bem
program define countrygrp_bem
  /*-----------------------
   WEU: EMU (3), OWE (6);
   OIN: OIN (5);
   CEE: CEE (2); 
   DEV: APC (1), ODV (4) and RCA (7)
   --------------------------------------------*/
  tab cntrygrp_bem
  gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
  replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
  replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
  replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
  label var cntrybemgrp "Country group BEM"
  rename cntrybemgrp _cntrybemgrp
  encode _cntrybemgrp, gen(cntrybemgrp) label(cntrybem)
  drop _cntrybemgrp
end


/*----------------------------*/
/* External data preperation  */
/*----------------------------*/

use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

global bef_reshape_1996 "`bef_reshape_1996'"
global bef_reshape_2000 "`bef_reshape_2000'"
global wage_diff_1996 "`wage_diff_1996'"
global wage_diff_2000 "`wage_diff_2000'"
do $dpref/#wage-diff-$waglvl.do

global addlfile "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff.dta"
global addlfirm "`addlfirm'"
global addlaffl "`addlaffl'"
global addlsec_1996 "`addlsec_1996'"
global addlsec_2000 "`addlsec_2000'"
do $dpref/#addlvars.do


/*-----------*/
/* MAIN FILE */
/*-----------*/


use "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff.dta", clear

sort country 
merge country using `cntrgrpbem' 
tab _merge
keep if _merge==3
drop _merge

countrygrp_bem
keep firmid ustan cntrybemgrp year nace1 sec1_bem inter

count
collapse (max) ustan nace1 sec1_bem inter, by(firmid cntrybemgrp year)  /* firmid's and ustan id's one-to-one */
count
fillin firmid cntrybemgrp year
count
gen byte chosen=(_fillin~=1)
label var inter "Intern'lization (#+1)"
label var nace1 "NACE 1.1 2-digit Sector code"
label var sec1_bem "Sector codes (BEM)"

preserve
keep if chosen==1
keep firmid ustan 
sort firmid
save `merge_ustan'
restore

sort firmid
merge firmid using `merge_ustan', update
count if _merge~=3 & _merge~=4
if r(N)~=0 {
  disp as error "_merge ~=3 & ~=4 exists"
  tab _merge
  STOP;
  }
drop _merge

preserve
keep if chosen==1
keep firmid nace1 sec1_bem inter year
sort firmid year
save `merge_sec'
restore

sort firmid year
merge firmid year using `merge_sec', update 
count if _merge~=3 & _merge~=4 & _merge~=1  /* _merge==1 are missing, meaning the MNE did not exsist at this time */
if r(N)~=0 {
  disp as error "_merge ~=3 & ~=4 exists"
  tab _merge
  STOP;
  }
tab _merge chosen

drop _merge _fillin


* merge ustan information for proper years

do $dpref/#parinfo-probit.do

gen profeqtyrat_par=profits_par/equity_par
label var profeqtyrat_par "Profits per equity parent"
gen caplabrat_par = (fixdasst_par/employmt_par) / 1
label var caplabrat_par "Cap'l/lab par [Thd EUR pc]"
keep firmid ustan year cntrybemgrp chosen nace1 sec1_bem employmt_par exports_par intmed_par wb_par fixdasst_par assettot_par profits_par turnover_par equity_par liab_par inter caplabrat_par profeqtyrat_par
label var ustan "Ustan ID"

* Take natural logs (parent (ustan) specific variables) 

* foreach var in employmt_par fixdasst_par assettot_par profits_par turnover_par equity_par liab_par inter caplabrat_par exports_par intmed_par wb_par {
foreach var in inter {
  gen ln_`var'=log(`var')
  local lbl : variable label `var'
  local lbl = subinstr("`lbl'","Profits bef. tax","Profit bftax",.)
  local lbl = subinstr("`lbl'","Debt (short & long term)","Debt (shrt&lng trm)",.)
  label var ln_`var' "ln `lbl'"
  drop `var'
  }

* reshape and label for mvprobit

foreach name in employmt_par fixdasst_par assettot_par profits_par turnover_par equity_par liab_par caplabrat_par exports_par intmed_par wb_par {
  forvalues i=1996(4)2000 {
    local lblyr = substr("`i'",-2,2)
    local lbl : variable label `name'
    qui gen `name'_`i'= `name'
    qui replace  `name'_`i'=. if year~=`i'
    bysort firmid: egen _help=max (`name'_`i')
    replace `name'_`i'=_help if `name'_`i'==.
    label var `name'_`i' "`lbl' `lblyr'"
    drop _help
    local lbl_reshp_1 : variable label `name'
    }
  drop `name'
  }

* foreach name in employmt_par fixdasst_par assettot_par profits_par turnover_par equity_par liab_par inter caplabrat_par exports_par intmed_par wb_par {
foreach name in inter {
  forvalues i=1996(4)2000 {
    local lblyr = substr("`i'",-2,2)
    local lbl : variable label ln_`name'
    qui gen ln_`name'_`i'= ln_`name'
    qui replace  ln_`name'_`i'=. if year~=`i'
    bysort firmid: egen _help=max (ln_`name'_`i')
    replace ln_`name'_`i'=_help if ln_`name'_`i'==.
    label var ln_`name'_`i' "`lbl' `lblyr'"
    drop _help
    local lbl_reshp_1 : variable label ln_`name'
    }
  drop ln_`name'
  }

foreach name in profeqtyrat_par nace1 sec1_bem {
  forvalues i=1996(4)2000 {
    local lblyr = substr("`i'",-2,2)
    local lbl : variable label `name'
    gen `name'_`i'= `name'
    replace `name'_`i'=. if year~=`i'
    bysort firmid: egen _help = max(`name'_`i')
    replace `name'_`i'=_help if `name'_`i'==.
    label var `name'_`i' "`lbl' `lblyr'"
    drop _help
    local lbl_reshp_2 : variable label `name'
    }
  drop `name'
  }

replace nace1_1996=nace1_2000 if nace1_1996==. /* fill missing sectors */
replace nace1_2000=nace1_1996 if nace1_2000==.
replace sec1_bem_1996=sec1_bem_2000 if sec1_bem_1996==. /* fill missing sectors */
replace sec1_bem_2000=sec1_bem_1996 if sec1_bem_2000==.
replace ln_inter_1996=0 if  ln_inter_1996==. /* fill in inter==1 if no FDI  */
replace ln_inter_2000=0 if  ln_inter_2000==.

gen region_year= cntrybemgrp*100000+year
keep if year==1996 | year==2000
drop year cntrybemgrp
duplicates drop
reshape wide chosen, i(firmid ustan) j(region_year)

local i=0
foreach name in CEE DEV OIN WEU {
  local i=`i'+10
  forvalues j=1996(4)2000 {
    local lblyr = substr("`j'",-2,2)
    rename chosen`i'`j' chosen_`name'_`j'
    label var chosen_`name'_`j' "FDI presence `name' `lblyr'"
    }
  }


* merge additional parent-level variables

sort firmid
merge firmid using ${addlfirm}, nokeep
tab _m
drop _m

* merge additional affiliate-level variables

sort firmid
merge firmid using ${addlaffl}, nokeep
tab _m
drop _m

* merge variables that do not vary over firmid

forvalues j=1996(4)2000 {
  local lblyr = substr("`j'",-2,2)
  cap drop _merge
  rename nace1_`j' nace1
  sort nace1 
  merge nace1 using `wage_diff_`j'', nokeep
  tab _merge
  drop _merge wagediff_CEE wagediff_DEV wagediff_OIN wagediff_WEU
  rename w_HOM w_HOM_`j'
  foreach var of varlist ln_wagediff_CEE ln_wagediff_DEV ln_wagediff_OIN ln_wagediff_WEU {
    local lblsec = substr("`var'",-3,23)
    rename `var' `var'_`j'
    label var `var'_`j' "ln Wage diff `lblsec' `lblyr'"
    }
  sort nace1
  merge nace1 using ${addlsec_`j'}, nokeep
  tab _m
  drop _m nace1 sec1_bem_`j'
  }

compress
rename firmid mneid
drop ustan
* order mneid chosen_CEE_1996 chosen_CEE_2000 chosen_DEV_1996 chosen_DEV_2000 chosen_OIN_1996 chosen_OIN_2000 chosen_WEU_1996 chosen_WEU_2000 w_HOM_1996 ln_wagediff_CEE_1996 ln_wagediff_DEV_1996 ln_wagediff_OIN_1996 ln_wagediff_WEU_1996 union_1996 w_HOM_2000 ln_wagediff_CEE_2000 ln_wagediff_DEV_2000 ln_wagediff_OIN_2000 ln_wagediff_WEU_2000 union_2000 imp_CEE_2000 exp_CEE_2000 impinp_CEE_2000 imp_DEV_2000 exp_DEV_2000 impinp_DEV_2000 imp_OIN_2000 exp_OIN_2000 impinp_OIN_2000 imp_WEU_2000 exp_WEU_2000 impinp_WEU_2000 state_par_1996 indwest_par_1996 state_par_2000 indwest_par_2000 ln_employmt_par_1996 ln_employmt_par_2000 ln_exports_par_1996 ln_intmed_par_1996 ln_wb_par_1996 ln_exports_par_2000 ln_intmed_par_2000 ln_wb_par_2000 ln_fixdasst_par_1996 ln_fixdasst_par_2000 ln_assettot_par_1996 ln_assettot_par_2000 ln_profits_par_1996 ln_profits_par_2000 ln_turnover_par_1996 ln_turnover_par_2000 ln_equity_par_1996 ln_equity_par_2000 ln_liab_par_1996 ln_liab_par_2000 ln_inter_1996 ln_inter_2000 ln_caplabrat_par_1996 ln_caplabrat_par_2000 profeqtyrat_par_1996 profeqtyrat_par_2000
order mneid chosen_CEE_1996 chosen_CEE_2000 chosen_DEV_1996 chosen_DEV_2000 chosen_OIN_1996 chosen_OIN_2000 chosen_WEU_1996 chosen_WEU_2000 w_HOM_1996 ln_inter_1996 ln_inter_2000 ln_wagediff_CEE_1996 ln_wagediff_DEV_1996 ln_wagediff_OIN_1996 ln_wagediff_WEU_1996 union_1996 w_HOM_2000 ln_wagediff_CEE_2000 ln_wagediff_DEV_2000 ln_wagediff_OIN_2000 ln_wagediff_WEU_2000 union_2000 imp_CEE_2000 exp_CEE_2000 impinp_CEE_2000 imp_DEV_2000 exp_DEV_2000 impinp_DEV_2000 imp_OIN_2000 exp_OIN_2000 impinp_OIN_2000 imp_WEU_2000 exp_WEU_2000 impinp_WEU_2000 state_par_1996 indwest_par_1996 state_par_2000 indwest_par_2000 employmt_par_1996 employmt_par_2000 exports_par_1996 intmed_par_1996 wb_par_1996 exports_par_2000 intmed_par_2000 wb_par_2000 fixdasst_par_1996 fixdasst_par_2000 assettot_par_1996 assettot_par_2000 profits_par_1996 profits_par_2000 turnover_par_1996 turnover_par_2000 equity_par_1996 equity_par_2000 liab_par_1996 liab_par_2000 caplabrat_par_1996 caplabrat_par_2000 profeqtyrat_par_1996 profeqtyrat_par_2000
sort mneid

save "$rootslct/Xdata/mvprobit-outwfdi-ustan-2000-$waglvl-pt$par-af$aff.dta", replace

log close
