*! version 1.4.2  26nov2006  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.3  28jun2009  by Marc Muendler  muendler@ucsd.edu

* replace `maxiter' with $maxiter

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/translog-selct-bstrap-pt$par-af$aff-$waglvl-nonparam-allyrs-ar2.log", replace

global poly 2  /* use second-order polynomials only; 1 2 3 possible */

*----------------------following code similar to translog-selct-2stp-bstrap-cf-nonparam.do----------------------------
*-----substitute: /v6npfsar2 for /v6np, now for 00, ${yrdiff}yrlg for 96 -------------------------------------------------------------------------
*-----substitute: Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs for Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam --

local reps = $reps
* ISUR with maximum number of iterations to avert non-convergence under bootstraps

#delimit ;

adopath + "$root/%stata/ado"; 


/* estimation routine */
/*--------------------*/
capture program drop surenp;
program define surenp;
  syntax [namelist], pscoresce(string) pscoresde(string) pscoresoi(string) pscoreswe(string) usemissg(integer);

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local namelist`r2dg' "";
    tokenize `namelist';
    local num :  word count `namelist';
    forvalues i = 1/`num' {;
      if substr("``i''",1,5)~="nofdi"  local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.);
      else                             local var = "``i''";
      local namelist`r2dg' "`namelist`r2dg'' `var'";
      };
    };

  * sector dummies;
  qui summ sec1_bem;
  local minsec = `r(min)'+1;
  local maxsec = `r(max)';
  local dumlst = "_Isec1_bem_`minsec'";
  local secdum = "_b[_Isec1_bem_`minsec']*_Isec1_bem_`minsec'";
  local secavgdum = "_b[_Isec1_bem_`minsec']*_MN_Isec1_bem_`minsec'";
  local minsec = `minsec' + 1;
  forvalues j = `minsec'/`maxsec' {;
    local dumlst "`dumlst' _Isec1_bem_`j'";
    local secdum "`secdum' + _b[_Isec1_bem_`j']*_Isec1_bem_`j'";
    local secavgdum "`secavgdum' + _b[_Isec1_bem_`j']*_MN_Isec1_bem_`j'";
    };

  * matrices for marginal effects of wages on selection and of propensity scores on labor demand;
  mat pscdlnw = J(4,5,.);
  mat suredps = J(4,4,0);
  matrix rownames pscdlnw = $regagg;
  matrix rownames suredps = $regagg;
  matrix colnames pscdlnw = HOM $regagg;
  matrix colnames suredps = $regagg;
  local rownames : rowfullnames pscdlnw;
  local rownum : word count `rownames';
  tokenize `rownames';
  forvalues rowi = 1/`rownum' {;
    local rownew = "i_" + substr("``rowi''",-3,3);
    matname pscdlnw `rownew', rows(`rowi') explicit;
    local rownew = "y_" + substr("``rowi''",-3,3);
    matname suredps `rownew', rows(`rowi') explicit;
    };
  local colnames : colfullnames pscdlnw;
  local colnum : word count `colnames';
  tokenize `colnames';
  forvalues coli = 1/`colnum' {;
    local colnew = "w_" + substr("``coli''",-3,3);
    matname pscdlnw `colnew', columns(`coli') explicit;
    };
  local colnames : colfullnames suredps;
  local colnum : word count `colnames';
  tokenize `colnames';
  forvalues coli = 1/`colnum' {;
    local colnew = "ps_" + substr("``coli''",-3,3);
    matname suredps `colnew', columns(`coli') explicit;
    };

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    tempname chk;

  * identify polynomial interaction terms;
  local selser1 = subinstr(subinstr("${par_1}","_othr","",.),"ln_","",.);
  local selser2 ""; /* second-order terms */
  local cnt 0;
  foreach var of local selser1 {;
    local cnt = `cnt' + 1;
    tokenize `selser1';
    local selno : word count `selser1';
    forvalues i = `cnt'/`selno' {;
      local addtrm = subinstr("`var'_``i''","_w_","_",.);
      local selser2 "`selser2' `addtrm'";
      };
    };
  local selser3 ""; /* third-order terms */
  local cnt 0;
  foreach var of local selser1 {;
    tokenize `selser2';
    local selno : word count `selser2';
    forvalues i = 1/`selno' {;
      if index("`selser1'",substr("`var'",-3,3)) >= index("`selser1'",substr("``i''",-3,3)) {;
        local addtrm = subinstr("``i''_`var'","_w_","_",.);
        local selser3 "`selser3' `addtrm'";
        };
      };
    };

    * polynomial terms;
    local polytrms ${paruse};
    if ${poly}<=2  local polytrms : list polytrms - selser3;
    if ${poly}==1  local polytrms : list polytrms - selser2;
    
    * selection regressions without sector dummies (used for translog);
    local dumlst ""; /* no sector dummies */
    xtgee i`r2dg'now iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg i`r2dg'${yrdiff}yrlg_wHO `polytrms', family(gaussian) i(mneid) t(year) corr(ar 2) iterate(250); 
    predict double psc`r2dg', xb;

    * predict log wage residual;
    foreach reg2 in HOM $regagg {;
      local r2dg2 = substr("`reg2'",1,2);
      reg lnw_`r2dg2' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg i`r2dg'${yrdiff}yrlg_wHO `polytrms';
      predict double cf`r2dg'_wres`r2dg2', res;
      replace cf`r2dg'_wres`r2dg2' = cf`r2dg' * cf`r2dg'_wres`r2dg2';
      replace cf`r2dg'_wres`r2dg2' = 0 if cf`r2dg'_wres`r2dg2'==.;
      };

    * observation-specific predictions for extensive margins, selection part;
      tokenize `polytrms' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `dumlst';
      local regrno : word count `polytrms' iCE${yrdiff}yrlg iDE${yrdiff}yrlg iOI${yrdiff}yrlg iWE${yrdiff}yrlg `dumlst';
      forvalues i = 1/`regrno' {;
        local varname = subinstr("_MN``i''","othr_","",.);
        qui egen double `varname' = mean(``i'') if e(sample);
        };
      * operate on: w_HOM w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU w_HOM_2 w_othr_CEE_2 w_othr_DEV_2 w_othr_OIN_2 w_othr_WEU_2;
      *        and  w_HOM_CEE w_HOM_DEV w_HOM_OIN w_HOM_WEU w_HOM_inter w_HOM_mktacc w_CEE_DEV w_CEE_OIN w_CEE_WEU w_CEE_inter w_CEE_mktacc w_DEV_OIN w_DEV_WEU w_DEV_inter w_DEV_mktacc w_OIN_WEU w_OIN_inter w_OIN_mktacc;
      *        etc.;

      * Evaluation of wage effects;
      tokenize `polytrms';
      local regrno : word count `polytrms';
      foreach wreg in HOM $regagg {;
        local predacc "_b[_cons]";  /* predicted poynomial terms, varying only by `wreg' wage (all other vars are sample means) */
        * local restavgacc "`secavgdum' + _b[iCE${yrdiff}yrlg]*_MNiCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*_MNiDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*_MNiOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*_MNiWE${yrdiff}yrlg";  /* predicted remaining terms, not varying (sample means) */
        local restavgacc "_b[iCE${yrdiff}yrlg]*_MNiCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*_MNiDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*_MNiOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*_MNiWE${yrdiff}yrlg";  /* predicted remaining terms, not varying (sample means) */
        * local restacc "`secdum' + _b[iCE${yrdiff}yrlg]*iCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*iDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*iOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*iWE${yrdiff}yrlg";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local restacc "_b[iCE${yrdiff}yrlg]*iCE${yrdiff}yrlg + _b[iDE${yrdiff}yrlg]*iDE${yrdiff}yrlg + _b[iOI${yrdiff}yrlg]*iOI${yrdiff}yrlg + _b[iWE${yrdiff}yrlg]*iWE${yrdiff}yrlg";  /* predicted remaining terms, varying by all variables for standard error calculation */
        local matacc "0";  /* marginal effect of `wreg' wage */
        * local chkacc "`predacc' + `restacc'";  /* for consistency checks (disabled) */
        local w2dg = substr("`wreg'",1,2);
        local regvar = "w_othr_`wreg'";
        if "`wreg'"=="HOM"  local regvar = "w_`wreg'";
        forvalues i = 1/`regrno' {;
          if length(subinstr("``i''","`wreg'","",.)) < length("``i''") {;  /* wage variable appears in token: treat */
            if lower(subinstr("``i''","`wreg'","",.)) == subinstr("``i''","`wreg'","",.) & substr(subinstr("``i''","`wreg'","",.),-1,1)=="_" {;  /* only `wreg' terms appear in token */
              local predacc "`predacc' + _b[``i'']*``i''";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  {; 
                if substr("`wreg'",-3,3)=="HOM" local matacc "`matacc' + _b[``i''] + _b[i`r2dg'${yrdiff}yrlg_w`w2dg']*_MNi`r2dg'${yrdiff}yrlg";
                else                            local matacc "`matacc' + _b[``i''] + _b[i`w2dg'${yrdiff}yrlg_w`w2dg']*_MNi`w2dg'${yrdiff}yrlg";
                };
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-9  local matacc "`matacc' + 3*_b[``i'']*w_`wreg'_`wreg'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            else {; /* mixed `wreg' and other terms appear in token */
              local covar = "_MN" + subinstr(subinstr(subinstr(subinstr("``i''","`wreg'","",.),"__","_",.),"__","_",.),"othr_","",.);
              if substr("`covar'",-1,1)=="_"  local covar = substr("`covar'",1,length("`covar'")-1);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'")<=12  local covar = subinstr("`covar'","w_","ln_",.);
              if lower(subinstr("`covar'","_MN","",.))==subinstr("`covar'","_MN","",.) & length("`covar'") >12  local covar = subinstr("`covar'","w_","",.);
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local predacc "`predacc' + _b[``i'']*`regvar'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local predacc "`predacc' + _b[``i'']*w_`wreg'_`wreg'*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-3  local matacc "`matacc' + _b[``i'']*`covar'";
              if length(subinstr("``i''","`wreg'","",.)) == length("``i''")-6  local matacc "`matacc' + 2*_b[``i'']*`regvar'*`covar'";
              * local chkacc "`chkacc' + _b[``i'']*``i''";
              };
            };
          if length(subinstr("``i''","`wreg'","",.)) == length("``i''") {;  /* wage variable does not appear in token: store for mean subtraction */
            local exclvar = subinstr("``i''","othr_","",.);
            local restavgacc "`restavgacc' + _b[``i'']*_MN`exclvar'";
            local restacc "`restacc' + _b[``i'']*``i''";
            * local chkacc "`chkacc' + _b[``i'']*``i''";
            };
          };
        * disp in yellow "`predacc'"; * disp in yellow "`restacc'"; * disp in yellow "`restavgacc'"; * disp in yellow "`matacc'";
        qui gen double dpsc`r2dg'dw`w2dg' = `predacc' + `restavgacc' if e(sample);
        * qui gen double __chkacc = `chkacc' if e(sample);
        * summ __chkacc psc`r2dg';  /* check identity */
        * drop __chkacc;
        qui gen double _mpsc`r2dg'w`w2dg' = `matacc' if e(sample);
        qui summ _mpsc`r2dg'w`w2dg', meanonly;
        mat pscdlnw[rownumb(pscdlnw,"i_`reg'"),colnumb(pscdlnw,"w_`wreg'")] = `r(mean)';
        * drop _mpsc`r2dg'w`w2dg'; 
        }; /* close wreg loop */
      drop _MN*;
    };  /* close reg loop */

  * generate polynomial interaction terms for sureg regression;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    qui gen byte ifdi`r2dg' = 1 - nofdi`r2dg';
    qui gen double psc`r2dg'_`r2dg' = psc`r2dg'*psc`r2dg';
    qui gen double psc`r2dg'_`r2dg'_`r2dg' = psc`r2dg'_`r2dg'*psc`r2dg';
    };
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local r2dglw = lower(substr("`reg'",1,2));
    local pscser`r2dg';
    foreach var of local pscores`r2dglw' {;
      local namvar = subinstr("`var'","*","_",.);
      capture qui gen double `namvar' = `var';
      local pscser`r2dg' "`pscser`r2dg'' `namvar'";
      };
    };

  * second step: seemingly unrelated regressions;
  if `usemissg' == 0 {;
  sureg (sCE: yCE = `namelistCE' cfCE `pscserCE')
        (sDE: yDE = `namelistDE' cfDE `pscserDE')
        (sOI: yOI = `namelistOI' cfOI `pscserOI')
        (sWE: yWE = `namelistWE' cfWE `pscserWE')
        , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
  *     (sHO: yHO = `namelistHO' cfHO `pscserHO'); /* left-out equation */
  };
  if `usemissg' == 1 {;
  sureg (sCE: yCE = `namelistCE' nofdiDE nofdiOI nofdiWE cfCE `pscserCE')
        (sDE: yDE = `namelistDE' nofdiCE nofdiOI nofdiWE cfDE `pscserDE')
        (sOI: yOI = `namelistOI' nofdiCE nofdiDE nofdiWE cfOI `pscserOI')
        (sWE: yWE = `namelistWE' nofdiCE nofdiDE nofdiOI cfWE `pscserWE')
        , constraints(2 3 4 6 7 9 12 13 14 15) corr isur iterate($maxiter);
  *     (sHO: yHO = `namelistHO' nofdiCE nofdiDE nofdiOI nofdiWE cfHO `pscserHO'); /* left-out equation */
  };
  local collbl "wHO wWE wOI wCE wDE";
  local rowlbl "sWE sOI sCE sDE";
  mat coefmat = J(5,5,.);
  local i = 1;
  foreach lreg in `rowlbl' {;
    local eqlbl = substr("`lreg'",2,2);
    local i = `i' + 1;
    local j = 0;
    foreach wreg in `collbl'{;
      local j = `j' + 1;
      mat coefmat[`i',`j'] = _b[`lreg':cf`eqlbl'_`wreg'];
      };
    mat coefmat[1,`i']= _b[`lreg':cf`eqlbl'_wHO];
    };
  mat coefmat[1,1] = - (coefmat[2,1] + coefmat[3,1] + coefmat[4,1] + coefmat[5,1]);
  local rowlbl "sHO `rowlbl'";
  matname coefmat `collbl', columns(1..5) explicit;
  matname coefmat `rowlbl', rows(1..5) explicit;

  * observation-specific predictions for extensive margins, sureg part;
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    egen double _MNifdi`r2dg' = mean(ifdi`r2dg') if e(sample);
    };
  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    * Evaluation of selection effects;
      local pspredacc "_b[s`r2dg':_cons]"; 
      local psrestacc "0";
      local psrestavgacc "0";
      local pspredacc "`pspredacc' + _b[s`r2dg':psc`r2dg']*psc`r2dg' + _b[s`r2dg':psc`r2dg'_`r2dg']*psc`r2dg'_`r2dg' + _b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg']*psc`r2dg'_`r2dg'_`r2dg'";
      local psmatacc "_b[s`r2dg':psc`r2dg'] + 2*_b[s`r2dg':psc`r2dg'_`r2dg']*psc`r2dg' + 3*_b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg']*psc`r2dg'_`r2dg'";
      local restreg : list global(regagg) - local(reg);
      foreach wreg in `restreg' {;
        local w2dg = substr("`wreg'",1,2);
        local addpred "_b[s`r2dg':psc`r2dg'_ifdi`w2dg']*psc`r2dg'*_MNifdi`w2dg' + _b[s`r2dg':psc`r2dg'_`r2dg'_ifdi`w2dg']*psc`r2dg'_`r2dg'*_MNifdi`w2dg' + _b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg'_ifdi`w2dg']*psc`r2dg'_`r2dg'_`r2dg'*_MNifdi`w2dg'";
        local addmat  "_b[s`r2dg':psc`r2dg'_ifdi`w2dg']*_MNifdi`w2dg' + 2*_b[s`r2dg':psc`r2dg'_`r2dg'*_MNifdi`w2dg']*psc`r2dg'*_MNifdi`w2dg' + 3*_b[s`r2dg':psc`r2dg'_`r2dg'_`r2dg'_ifdi`w2dg']*psc`r2dg'_`r2dg'*_MNifdi`w2dg'";
        local pspredacc "`pspredacc' + `addpred'";
        local psmatacc "`psmatacc' + `addpred'";
        }; /* close wreg loop */
      * disp in yellow "`pspredacc'"; * disp in yellow "`psrestacc'"; * disp in yellow "`psrestavgacc'";
      qui gen double dy`r2dg'dps`r2dg' = `pspredacc' + `psrestavgacc' if e(sample);
      qui gen double _mdy`r2dg'psc`r2dg' = `psmatacc' if e(sample);
      qui summ _mdy`r2dg'psc`r2dg', meanonly;
      mat suredps[rownumb(suredps,"y_`reg'"),colnumb(suredps,"ps_`reg'")] = `r(mean)';
      * CIs from SE of prediction (default);
      qui gen double dy`r2dg'dps`r2dg'_se = y`r2dg' - dy`r2dg'dps`r2dg' + `psrestavgacc' - `psrestacc' if e(sample);
      qui gen double dy`r2dg'dps`r2dg'_lcl = dy`r2dg'dps`r2dg' - invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`r2dg'_se if e(sample);
      qui gen double dy`r2dg'dps`r2dg'_ucl = dy`r2dg'dps`r2dg' + invttail(e(df_m1),((100-${S_level})/200)) * dy`r2dg'dps`r2dg'_se if e(sample);
      label var dy`r2dg'dps`r2dg' "Selection i`r2dg' effect on labor demand y`r2dg'";
      label var dy`r2dg'dps`r2dg'_lcl "${S_level}% CI i`r2dg' eff on empl y`r2dg'";
      label var dy`r2dg'dps`r2dg'_ucl "${S_level}% CI i`r2dg' eff on empl y`r2dg'";
      * sort psc`r2dg';
      * twoway connected dy`r2dg'dps`r2dg' dy`r2dg'dps`r2dg'_lcl dy`r2dg'dps`r2dg'_ucl psc`r2dg' if psc`r2dg'>=0 & psc`r2dg'<=1;
      * twoway connected dy`r2dg'dps`r2dg' psc`r2dg' if psc`r2dg'>=0 & psc`r2dg'<=1;
      drop dy`r2dg'dps`r2dg'_se;
      * drop _mdy`r2dg'psc`r2dg';    
    }; /* close reg loop */
  drop _MN*;

  * observation-specific extensive margins;
  tempname suredlnw;
  mat `suredlnw' = suredps * pscdlnw;
  foreach weff in HOM $regagg {;
    local w2dg = substr("`weff'",1,2);
    gen double xmrHOw`w2dg' = 0;
    foreach reg in $regagg {;
      local r2dg = substr("`reg'",1,2);
      local regvar = "w_othr_`weff'";
      if "`weff'"=="HOM"  local regvar = "w_`weff'";
      local dpsc`r2dg'dw`w2dg' = `suredlnw'[rownumb(`suredlnw',"y_`reg'"),colnumb(`suredlnw',"w_`weff'")];
      * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now / cf`r2dg' ; /* if log wages used; observations */
      * qui gen double xmr`r2dg'w`w2dg' = (_mdy`r2dg'pscCE*_mpscCEw`w2dg' + _mdy`r2dg'pscDE*_mpscDEw`w2dg' + _mdy`r2dg'pscOI*_mpscOIw`w2dg' + _mdy`r2dg'pscWE*_mpscWEw`w2dg') * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; observations */
      * qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now / cf`r2dg' ; /* if log wages used; mean matrix */
      qui gen double xmr`r2dg'w`w2dg' = `dpsc`r2dg'dw`w2dg'' * i`r2dg'now * `regvar' / cf`r2dg' ; /* if plain wages used; mean matrix */
      replace xmr`r2dg'w`w2dg'=. if abs(xmr`r2dg'w`w2dg')>1;  /* disregard implausible outliers */
      };
    };
 
  * Matrix of mean extensive margin correction terms;
  capture mat drop xmrmat;
  local rownames : rowfullnames coefmat;  /* Match regional pattern in coefmat at intensive margin */
  local colnames : colfullnames coefmat;
  local colnum : word count `colnames';
  foreach reg in `rownames' {;
    local r2dg = substr("`reg'",-2,2);
    tempname xmat`r2dg';
    mat `xmat`r2dg'' = J(1,`colnum',.);
    matname `xmat`r2dg'' s`r2dg', rows(1) explicit;
    local colj = 0;
    foreach weff in `colnames' {;
      local colj = `colj' + 1;
      qui summ xmr`r2dg'`weff' if s`r2dg'~=0 & e(sample), meanonly;  /* only calculate mean over sample MNEs with presence */
      mat `xmat`r2dg''[1,`colj'] = r(mean);
      matname `xmat`r2dg'' `weff', columns(`colj') explicit;
      };
    capture mat xmrmat = xmrmat \ `xmat`r2dg'';
    if _rc {;
      mat xmrmat = `xmat`r2dg'';
      };
    };

  calcelastnp;
end;


/* elasticity posting */
/*--------------------*/
capture program drop calcelastnp;
program define calcelastnp, rclass;
  foreach reg in WE OI CE DE {;
    * qui predict double shat`reg', equation(s`reg') xb, if e(sample);
    qui gen double shat`reg' = s`reg';
    };
  qui gen double shatHO = sHO;
  preserve;
  collapse (mean) shatHO shatWE shatOI shatCE shatDE if e(sample), fast;
  mkmat shatHO shatWE shatOI shatCE shatDE, matrix(Tmat);  /* Tmat to be transposed to a column vector next */
  matname Tmat theta, rows(1) explicit;
  mat Tmat = Tmat';  /* Tmat transposed to a column vector */
  mat Tsqmat = Tmat * Tmat';

  * Calculate total cross-price elasticities (both margins);
  mat TotElast = coefmat + xmrmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat TotElast[`r',`m'] = TotElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {; /* Fill diagonal entries */
      mat TotElast[`r',`r'] = TotElast[`r',`r'] / Tmat[`r',1] - 1;
    };

  * Calculate cross-price elasticities matrix at extensive margin;
  mat ExtElast = xmrmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat ExtElast[`r',`m'] = ExtElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries and cancel HOM row */
      mat ExtElast[`r',`r'] = ExtElast[`r',`r'] / Tmat[`r',1] - 1;
      mat ExtElast[1,`r'] = 0;
    };

  * Calculate cross-price elasticities matrix at intensive margin;
  mat IntElast = coefmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries */
      mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
    };

  * assemble elasticity estimate in one vector;
  foreach elsttyp in Int Ext Tot {;
    local cols = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + colsof(`elsttyp'Elast);
    mat b`elsttyp'Elast = J(1,`cols',.);
    local i = 0;
    foreach regi in HO WE OI CE DE {;
      local i = `i' + 1;
      local j = 0;
      foreach regj in HO WE OI CE DE {;
        local j = `j' + 1;
        local col = (`i'-1)*colsof(`elsttyp'Elast) + `j';
        mat b`elsttyp'Elast[1,`col'] = `elsttyp'Elast[`i',`j'];
        matname b`elsttyp'Elast `elsttyp'_l`regi'_w`regj', columns(`col') explicit;
        };
      local thetacol = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + `i';
      qui summ shat`regi', meanonly;
      mat b`elsttyp'Elast[1,`thetacol'] = `r(mean)';
      matname b`elsttyp'Elast `elsttyp'_s`regi'mean, columns(`thetacol') explicit;
      };
    };
  mat bElast = bTotElast , bExtElast , bIntElast;
  restore;

  * drop entries with missing information (first entry missing will result in error);
  local j 1;
  local cols = colsof(bElast);
  while `j' <= `cols'-1 {;
    local j = `j' + 1;
    local cols = colsof(bElast);
    if bElast[1,`j']==. {;
      mat bElast = bElast[1,1..`j'-1] , bElast[1,`j'+1..`cols'];
      local j = `j' - 1;
      };
    };

  * tempvar touse; /* not used b/c two steps operate on different samples */
  * gen byte `touse' = e(sample);

  tempname pseudocov;
  local cols = colsof(bElast);
  local colnams : colfullnames bElast;
  matrix `pseudocov' = -999*I(`cols');
  matrix colnames `pseudocov' = `colnams';
  matrix rownames `pseudocov' = `colnams';

  * ereturn post bElast `pseudocov', esample(`touse');
  ereturn post bElast `pseudocov';
  
end;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sWE]cfWE_wHO = [sHO]cfHO_wWE;
  constraint define  2 [sWE]cfWE_wOI = [sOI]cfOI_wWE;
  constraint define  3 [sWE]cfWE_wCE = [sCE]cfCE_wWE;
  constraint define  4 [sWE]cfWE_wDE = [sDE]cfDE_wWE;
* constraint define  5 [sOI]cfOI_wHO = [sHO]cfHO_wOI;
  constraint define  6 [sOI]cfOI_wCE = [sCE]cfCE_wOI;
  constraint define  7 [sOI]cfOI_wDE = [sDE]cfDE_wOI;
* constraint define  8 [sCE]cfCE_wHO = [sHO]cfHO_wCE;
  constraint define  9 [sCE]cfCE_wDE = [sDE]cfDE_wCE;
* constraint define 10 [sDE]cfDE_wHO = [sHO]cfHO_wDE;
* constraint define 11 [sHO]cfHO_wHO + [sHO]cfHO_wWE + [sHO]cfHO_wOI + [sHO]cfHO_wCE + [sHO]cfHO_wDE = 0;
  constraint define 12 [sWE]cfWE_wHO + [sWE]cfWE_wWE + [sWE]cfWE_wOI + [sWE]cfWE_wCE + [sWE]cfWE_wDE = 0;
  constraint define 13 [sOI]cfOI_wHO + [sOI]cfOI_wWE + [sOI]cfOI_wOI + [sOI]cfOI_wCE + [sOI]cfOI_wDE = 0;
  constraint define 14 [sCE]cfCE_wHO + [sCE]cfCE_wWE + [sCE]cfCE_wOI + [sCE]cfCE_wCE + [sCE]cfCE_wDE = 0;
  constraint define 15 [sDE]cfDE_wHO + [sDE]cfDE_wWE + [sDE]cfDE_wOI + [sDE]cfDE_wCE + [sDE]cfDE_wDE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */

/* variable sets for selection estimation */
/*----------------------------------------*/

do $dp/!varsets-np.do;

/* nonparametric base variables for sureg estimation */
/*---------------------------------------------------*/

local dintact "ifdiCE ifdiDE ifdiWE ifdiOI";
foreach reg in $regagg {;
  local r2dg = substr("`reg'",1,2);
  local pscores`r2dg' "psc`r2dg' psc`r2dg'_`r2dg' psc`r2dg'_`r2dg'_`r2dg'";
  tokenize `pscores`r2dg'';
  local num : word count `pscores`r2dg'';
  local remtrm "ifdi`r2dg'";
  local multact : list dintact - remtrm;
  foreach dummy in `multact' {;
    forvalues i = 1/`num' {;
      local addtrm "``i''*`dummy'";
      local pscores`r2dg' "`pscores`r2dg'' `addtrm'";
      };
    };
  };
local pscno : word count `pscoresCE';


/* data and main loop */
/*--------------------*/

local howmany "";
if index("$howmany","1")~=0  local howmany 1;  /* only usemissg 1 permitted */
foreach usemissg in `howmany' {; /* begin `usemissg' loop */

capture mkdir "$rootslct/estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf";
capture mkdir "$rootslct/estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'";

use "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-nonparam-allyrs", clear;
drop dpsc??dw?? dpsc??dw??_lcl dpsc??dw??_ucl psc??;


/* Bootstrap SUR under restrictions */
/*----------------------------------*/

keep mneid year sec1_bem iHOnow iCEnow iDEnow iOInow iWEnow yHO yCE yDE yOI yWE sHO sCE sDE sOI sWE iCE${yrdiff}yrlg* iDE${yrdiff}yrlg* iOI${yrdiff}yrlg* iWE${yrdiff}yrlg* ${paruse} cf??_wHO cf??_wWE cf??_wOI cf??_wCE cf??_wDE cf??_tHO cf??_tWE cf??_tOI cf??_tCE cf??_tDE cf??_kHO cf??_kWE cf??_kOI cf??_kCE cf??_kDE nofdiWE nofdiOI nofdiCE nofdiDE cfHO cfWE cfOI cfCE cfDE lnw_??;
* surenp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE, pscoresce(`pscoresCE') pscoresde(`pscoresDE') pscoresoi(`pscoresOI') pscoreswe(`pscoresWE') usemissg(`usemissg');

bootstrap "surenp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE cf_wresHO cf_wresCE cf_wresDE cf_wresOI cf_wresWE, pscoresce(`pscoresCE') pscoresde(`pscoresDE') pscoresoi(`pscoresOI') pscoreswe(`pscoresWE') usemissg(`usemissg')" _b, 
        reps(`reps') double saving(estmat/v6npfsar2/pt$par-af$aff-$waglvl-cf/translog`usemissg'/elast`usemissg'_bstrap) every(50) dots replace cluster(mneid);

mat drop coefmat xmrmat TotElast ExtElast IntElast bTotElast bExtElast bIntElast Tmat Tsqmat pscdlnw suredps;

}; /* end of `usemissg' loop */

capture program drop surenp;
capture program drop calcelastnp;

*----------------------above code similar to translog-selct-2stp-bstrap-cf-nonparam.do------------------------------------;

log close;
cd "$root";
