*! version 1.0.4  20jul2009  by Marc Muendler  muendler@ucsd.edu
*! version 1.2.1  16sep2009  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 800
set more off
capture log close

cd "$rootslct"

log using "logs/comp-elast-ger-cf-aerrr.log", replace

local wag "uno"
local usemissg 1

capture mkdir "$rootslct/tex/comp"
capture mkdir "$rootslct/tex/comp/pt$par-af$aff-cf"
capture mkdir "$rootslct/tex/comp/pt$par-af$aff-frm`wag'wage-plainreg-cf"

mat drop _all

adopath + "$root/%stata/ado"

* variable labels
foreach mat in cmpintw_aerrr cmpextw_aerrr cmpinty_aerrr {
  capture est2extlbl, addto(`mat') retain p(tex/comp/pt$par-af$aff-cf) replace
  if _rc~=0  est2extlbl, addto(`mat') intex($rootdo/%stata/rowlbl-fdiselct) p(tex/comp/pt$par-af$aff-cf) replace
  }
est2extlbl, addto(plainreg`usemissg'_reldiff) retain p(tex/comp/pt$par-af$aff-frm`wag'wage-plainreg-cf) replace dropall
est2extlbl, addto(regkm_aerrr) retain p(tex/v6kmfs/pt$par-af$aff-$waglvl) replace dropall
est2extlbl, addto(regkm_aerrr2) retain p(tex/v6kmfs/pt$par-af$aff-$waglvl) replace dropall
est2extlbl, addto(regkm_aerrr2i) retain p(tex/v6kmfs/pt$par-af$aff-$waglvl) replace dropall
clear


* COMPARISON MATRIX FOR PLAINLY-UNCORRECTED ESTIMATES (no cross-equation restrictions)

capture matload intelast`usemissg'_tbl, p(tex/v6fs/pt$par-af$aff-frm`wag'wage-cf) over missing(.) dropall
if _rc==0 {
  matorder intelast`usemissg'_tbl, m(intelast`usemissg'_corrct) ifr(rLDemHO rLDemCE rLDemDE rLDemOI rLDemWE) over
  matload intelast`usemissg'_tbl, p(tex/v6fs/pt$par-af$aff-frm`wag'wage-plainreg-cf) over missing(.) dropall
  matorder intelast`usemissg'_tbl, m(intelast`usemissg'_plainreg) ifr(rLDemHO rLDemCE rLDemDE rLDemOI rLDemWE) over
  mat drop intelast`usemissg'_tbl 
  local rows = rowsof(intelast`usemissg'_corrct)
  local cols = colsof(intelast`usemissg'_corrct)
  local rownames : rowfullnames intelast`usemissg'_corrct
  local colnames : colfullnames intelast`usemissg'_corrct
  mat plainreg`usemissg'_reldiff_tbl = J(`rows',`cols',.)
  mat rownames plainreg`usemissg'_reldiff_tbl = `rownames'
  mat colnames plainreg`usemissg'_reldiff_tbl = `colnames'
  forvalues i = 1/`rows' {
    forvalues j = 1/`cols' {
      mat plainreg`usemissg'_reldiff_tbl[`i',`j'] = ( intelast`usemissg'_plainreg[`i',`j'] - intelast`usemissg'_corrct[`i',`j'] ) / intelast`usemissg'_corrct[`i',`j']
      }
    }
  est2tex plainreg`usemissg'_reldiff, replace dropall path(tex/comp/pt$par-af$aff-frm`wag'wage-plainreg-cf) fancy ready
  }
clear


* COMPARISON MATRICES OF ELASTICITIES

* home wage effects on foreign employment (first column of elasticity matrices)
foreach mat in int ext {
  matload cmp`mat'elastw_tbl, p(tex/v6npfs/pt$par-af$aff-frmunowage-cf) over missing(.)
  matrix coleq cmp`mat'elastw_tbl = fsuno
  mat rename cmp`mat'elastw_tbl cmp`mat'w_tbl
  matload cmp`mat'elastw_tbl, p(tex/v6npfs/pt$par-af$aff-frmowwwage-cf) over missing(.)
  matrix coleq cmp`mat'elastw_tbl = fsoww
  mat cmp`mat'w_tbl = cmp`mat'w_tbl , cmp`mat'elastw_tbl
  matload cmp`mat'elastw_tbl, p(tex/v6np/pt$par-af$aff-frmunowage-cf) over missing(.)
  matrix coleq cmp`mat'elastw_tbl = cruno
  mat cmp`mat'w_tbl = cmp`mat'w_tbl , cmp`mat'elastw_tbl
  mat drop cmp`mat'elastw_tbl
  matload cmp`mat'elastw_tbl, p(tex/v6wpremfs/pt$par-af$aff-frm`wag'wage-cf) over missing(.)
  matrix coleq cmp`mat'elastw_tbl = wprem`wag'
  mat cmp`mat'w_tbl = cmp`mat'w_tbl , cmp`mat'elastw_tbl
  mat drop cmp`mat'elastw_tbl
  local colnames : colnames cmp`mat'w_tbl
  tokenize `colnames'
  local num : word count `colnames'
  forvalues i = 1/`num' {
    local newname = subinstr("``i''","_mWageHO","",.)
    matname cmp`mat'w_tbl `newname', column(`i') explicit
    }
  matorder cmp`mat'w_tbl, m(cmp`mat'w_tbl) over ifc(fsuno:wHO1hm cruno:wHO1hm fsuno:wHO1ar2 wpremuno:wHO1lgefs fsoww:wHO1hm fsuno:wHO1npr fsuno:wHO0hm)
  mat rename cmp`mat'w_tbl cmp`mat'unow_aerrr_tbl
  est2tex cmp`mat'unow_aerrr, replace dropall preserve mark(starse) path(tex/comp/pt$par-af$aff-cf) fancy levels(90 95 99) ready
  }

* foreign wage effects on home employment (first row of elasticity matrices)
local mat "int"
  matload cmp`mat'elasty_tbl, p(tex/v6npfs/pt$par-af$aff-frmunowage-cf) over missing(.)
  local roweq : roweq cmp`mat'elasty_tbl
  local rows = rowsof(cmp`mat'elasty_tbl)
  tokenize `roweq'
  local newrows ""
  forvalues i = 1/`rows' {
    local newrows "`newrows' fsuno_``i''"
    }
  matrix roweq cmp`mat'elasty_tbl = `newrows'
  mat rename cmp`mat'elasty_tbl cmp`mat'y_tbl
  matload cmp`mat'elasty_tbl, p(tex/v6npfs/pt$par-af$aff-frmowwwage-cf) over missing(.)
  local roweq : roweq cmp`mat'elasty_tbl
  local rows = rowsof(cmp`mat'elasty_tbl)
  tokenize `roweq'
  local newrows ""
  forvalues i = 1/`rows' {
    local newrows "`newrows' fsoww_``i''"
    }
  matrix roweq cmp`mat'elasty_tbl = `newrows'
  mat cmp`mat'y_tbl = cmp`mat'y_tbl \ cmp`mat'elasty_tbl
  matload cmp`mat'elasty_tbl, p(tex/v6np/pt$par-af$aff-frmunowage-cf) over missing(.)
  local roweq : roweq cmp`mat'elasty_tbl
  local rows = rowsof(cmp`mat'elasty_tbl)
  tokenize `roweq'
  local newrows ""
  forvalues i = 1/`rows' {
    local newrows "`newrows' cruno_``i''"
    }
  matrix roweq cmp`mat'elasty_tbl = `newrows'
  mat cmp`mat'y_tbl = cmp`mat'y_tbl \ cmp`mat'elasty_tbl
  matload cmp`mat'elasty_tbl, p(tex/v6wpremfs/pt$par-af$aff-frm`wag'wage-cf) over missing(.)
  local roweq : roweq cmp`mat'elasty_tbl
  local rows = rowsof(cmp`mat'elasty_tbl)
  tokenize `roweq'
  local newrows ""
  forvalues i = 1/`rows' {
    local newrows "`newrows' wprem`wag'_``i''"
    }
  matrix roweq cmp`mat'elasty_tbl = `newrows'
  mat cmp`mat'y_tbl = cmp`mat'y_tbl \ cmp`mat'elasty_tbl
  matorder cmp`mat'y_tbl, m(cmp`mat'y_tbl) over ifr(fsuno_yHO1hm:rLDemHO fsuno_yHO1hm:_se cruno_yHO1hm:rLDemHO cruno_yHO1hm:_se fsuno_yHO1ar2:rLDemHO fsuno_yHO1ar2:_se wpremuno_yHO1lgefs:rLDemHO wpremuno_yHO1lgefs:_se fsoww_yHO1hm:rLDemHO fsoww_yHO1hm:_se fsuno_yHO1npr:rLDemHO fsuno_yHO1npr:_se fsuno_yHO0hm:rLDemHO fsuno_yHO0hm:_se)
  mat rename cmp`mat'y_tbl cmp`mat'unoy_aerrr_tbl
  est2tex cmp`mat'unoy_aerrr, replace dropall preserve mark(starse) path(tex/comp/pt$par-af$aff-cf) fancy levels(90 95 99) ready


* COMPARISON MATRIX WITH KONINGS-MARIN TYPE ESTIMATES

matload regkm_tbl, p(tex/v6kmfs/pt$par-af$aff-$waglvl) over dropall
matload intelast1_tbl, p(tex/v6fs/pt$par-af$aff-frmunowage-uncorrected-cf) over missing(.) dropall
mat rename intelast1_tbl uncorrctd_tbl
matload intelast1_tbl, p(tex/v6fs/pt$par-af$aff-frmunowage-cf) over missing(.) dropall
mat rename intelast1_tbl main_tbl
matload intelast1_tbl, p(tex/v6fefs/pt$par-af$aff-frmunowage-cf) over missing(.) dropall
mat rename intelast1_tbl mainfe_tbl
local mat "regkm_tbl"
  local rows = rowsof(`mat')
  local rownames : rownames `mat'
  tokenize `rownames'
  local newnames = ""
  forvalues i = 1/`rows' {
    if substr("``i''",1,3)=="_se"  local replname = "_`lastrow'``i''"
    else                           local replname = "``i''"
    local newnames "`newnames' `replname'"
    local lastrow = "``i''"
    }
  mat rownames `mat' = `newnames'
matorder regkm_tbl, m(regkm_aerrr_tbl) ifc(reg fe fe_tk fe_tk_ilg)
matorder regkm_aerrr_tbl, m(regkm_aerrr_tbl) ifr(wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se tHO _tHO_se e(r2) e(N)) over
foreach mat in uncorrctd main mainfe {
  mat _`mat' = `mat'_tbl'
  local se4pos = colnumb(_`mat',"rLDemHO")+2  // position of bootstrapped s.e.
  mat _`mat'_b = _`mat'[1...,colnumb(_`mat',"rLDemHO")]
  mat _`mat'_se = _`mat'[1...,`se4pos']
  mat _`mat'_e = _`mat'[1,colnumb(_`mat',"e(theta_N)")]
  est2one _`mat'
  mat rownames _`mat'_tbl = wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se e(N)
  matins _`mat'_tbl, m(_`mat'_tbl) ifr(wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se tHO _tHO_se e(r2) e(N)) over
  mat colnames _`mat'_tbl = `mat'
  }
mat regkm_aerrr_tbl = regkm_aerrr_tbl , _uncorrctd_tbl , _main_tbl  // cut: , _mainfe_tbl
mat coleq regkm_aerrr_tbl = sngl sngl sngl sngl sureg sureg
est2tex regkm_aerrr, replace dropall ready preserve mark(starse) p(tex/v6kmfs/pt$par-af$aff-$waglvl) fancy levels(90 95 99) extracols(4)


* SASCHA COMPARISON MATRIX WITH KONINGS-MARIN TYPE ESTIMATES

capture mat drop uncorrctd_tbl main_tbl mainfe_tbl _uncorrctd_tbl _main_tbl _mainfe_tbl
matload regkm_tbl, p(tex/v6kmfs/pt$par-af$aff-$waglvl) over dropall
matload intelast1_tbl, p(tex/v6fs/pt$par-af$aff-frmunowage-uncorrected-cf) over missing(.) dropall
mat rename intelast1_tbl uncorrctd_tbl
matload intelast1_tbl, p(tex/v6fs/pt$par-af$aff-frmunowage-cf) over missing(.) dropall
mat rename intelast1_tbl main_tbl
matload intelast1_tbl, p(tex/v6fefs/pt$par-af$aff-frmunowage-cf) over missing(.) dropall
mat rename intelast1_tbl mainfe_tbl
local mat "regkm_tbl"
  local rows = rowsof(`mat')
  local rownames : rownames `mat'
  tokenize `rownames'
  local newnames = ""
  forvalues i = 1/`rows' {
    if substr("``i''",1,3)=="_se"  local replname = "_`lastrow'``i''"
    else                           local replname = "``i''"
    local newnames "`newnames' `replname'"
    local lastrow = "``i''"
    }
  mat rownames `mat' = `newnames'
matorder regkm_tbl, m(regkm_aerrr2_tbl) ifc(km_tbl4_fe km_tbl4 km_tbl4_t km_tbl4_t_k km_tbl4_t_k_allreg)
matorder regkm_aerrr2_tbl, m(regkm_aerrr2_tbl) ifr(wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se tHO _tHO_se e(r2) e(N)) over
foreach mat in uncorrctd main mainfe {
  mat _`mat' = `mat'_tbl'
  local se4pos = colnumb(_`mat',"rLDemHO")+2  // position of bootstrapped s.e.
  mat _`mat'_b = _`mat'[1...,colnumb(_`mat',"rLDemHO")]
  mat _`mat'_se = _`mat'[1...,`se4pos']
  mat _`mat'_e = _`mat'[1,colnumb(_`mat',"e(theta_N)")]
  est2one _`mat'
  mat rownames _`mat'_tbl = wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se e(N)
  matins _`mat'_tbl, m(_`mat'_tbl) ifr(wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se tHO _tHO_se e(r2) e(N)) over
  mat colnames _`mat'_tbl = `mat'
  }
mat regkm_aerrr2_tbl = regkm_aerrr2_tbl , _uncorrctd_tbl , _main_tbl , _mainfe_tbl
mat coleq regkm_aerrr2_tbl = sngl sngl sngl sngl sngl sureg sureg sureg
est2tex regkm_aerrr2, replace dropall ready preserve mark(starse) p(tex/v6kmfs/pt$par-af$aff-$waglvl) fancy levels(90 95 99) extracols(5)


* AUGMENTED SASCHA COMPARISON MATRIX WITH KONINGS-MARIN TYPE ESTIMATES

capture mat drop uncorrctd_tbl main_tbl mainfe_tbl _uncorrctd_tbl _main_tbl _mainfe_tbl
matload regkm_tbl, p(tex/v6kmfs/pt$par-af$aff-$waglvl) over dropall
matload intelast1_tbl, p(tex/v6fs/pt$par-af$aff-frmunowage-uncorrected-cf) over missing(.) dropall
mat rename intelast1_tbl uncorrctd_tbl
matload intelast1_tbl, p(tex/v6fs/pt$par-af$aff-frmunowage-cf) over missing(.) dropall
mat rename intelast1_tbl main_tbl
matload intelast1_tbl, p(tex/v6fefs/pt$par-af$aff-frmunowage-cf) over missing(.) dropall
mat rename intelast1_tbl mainfe_tbl
local mat "regkm_tbl"
  local rows = rowsof(`mat')
  local rownames : rownames `mat'
  tokenize `rownames'
  local newnames = ""
  forvalues i = 1/`rows' {
    if substr("``i''",1,3)=="_se"  local replname = "_`lastrow'``i''"
    else                           local replname = "``i''"
    local newnames "`newnames' `replname'"
    local lastrow = "``i''"
    }
  mat rownames `mat' = `newnames'
matorder regkm_tbl, m(regkm_aerrr2i_tbl) ifc(kmi_tbl4 kmi_tbl4_t kmi_tbl4_t_k kmi_tbl4_t_k_allreg)
matorder regkm_aerrr2i_tbl, m(regkm_aerrr2i_tbl) ifr(wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se tHO _tHO_se e(r2) e(N)) over
foreach mat in uncorrctd main mainfe {
  mat _`mat' = `mat'_tbl'
  local se4pos = colnumb(_`mat',"rLDemHO")+2  // position of bootstrapped s.e.
  mat _`mat'_b = _`mat'[1...,colnumb(_`mat',"rLDemHO")]
  mat _`mat'_se = _`mat'[1...,`se4pos']
  mat _`mat'_e = _`mat'[1,colnumb(_`mat',"e(theta_N)")]
  est2one _`mat'
  mat rownames _`mat'_tbl = wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se e(N)
  matins _`mat'_tbl, m(_`mat'_tbl) ifr(wHO _wHO_se wCE _wCE_se wDE _wDE_se wOI _wOI_se wWE _wWE_se tHO _tHO_se e(r2) e(N)) over
  mat colnames _`mat'_tbl = `mat'
  }
mat regkm_aerrr2i_tbl = regkm_aerrr2i_tbl , _uncorrctd_tbl , _main_tbl , _mainfe_tbl
matorder regkm_aerrr2i_tbl, m(regkm_aerrr2i_tbl) ifc(kmi_tbl4 kmi_tbl4_t kmi_tbl4_t_k kmi_tbl4_t_k_allreg uncorrctd main) over
mat coleq regkm_aerrr2i_tbl = sngl sngl sngl sngl sureg sureg
est2tex regkm_aerrr2i, replace dropall ready preserve mark(starse) p(tex/v6kmfs/pt$par-af$aff-$waglvl) fancy levels(90 95 99) extracols(4)


* DPROBIT TABLES WITH RESCALED COEFFICIENTS FOR INCLUSION IN PAPER

foreach path in "v6fs/ptmanf-afmanf-frmunowage-cf" "v6fsar2/ptmanf-afmanf-frmunowage-cf" "v6fs/ptmanf-afall-frmunowage-cf" "v6fs/ptmanf-afmanf-frmowwwage-cf" {
est2extlbl, addto(dprobit_aerrr) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/`path') replace
use "tex/`path'/dprobit_txt_tbl.dta", clear
foreach reg in $regagg {
  local r2dg = upper(substr("`reg'",1,2))
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^3 if _rowname=="employmt_par_${yrdiff}yrlg" | _rowname[_n-1]=="employmt_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="fixdasst_par_${yrdiff}yrlg" | _rowname[_n-1]=="fixdasst_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="turnover_par_${yrdiff}yrlg" | _rowname[_n-1]=="turnover_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="intmed_par_${yrdiff}yrlg" | _rowname[_n-1]=="intmed_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="liab_par_${yrdiff}yrlg" | _rowname[_n-1]=="liab_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^3 if _rowname=="employmt_par_${yrdiff}yrlg" | _rowname[_n-1]=="employmt_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="fixdasst_par_${yrdiff}yrlg" | _rowname[_n-1]=="fixdasst_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="turnover_par_${yrdiff}yrlg" | _rowname[_n-1]=="turnover_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="intmed_par_${yrdiff}yrlg" | _rowname[_n-1]=="intmed_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="liab_par_${yrdiff}yrlg" | _rowname[_n-1]=="liab_par_${yrdiff}yrlg"
  }
save "tex/`path'/dprobit_aerrr_tbl.dta", replace
matload dprobit_aerrr_tbl, p(tex/`path') over missing(.) dropall
est2tex dprobit_aerrr, replace dropall ready preserve mark(starse) p(tex/`path') fancy levels(90 95 99)
}

foreach path in "v6qrtsfs/ptmanf-afmanf-frmunowage-cf" {
est2extlbl, addto(dprobit_aerrr) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/`path') replace
use "tex/`path'/dprobit_txt_tbl.dta", clear
foreach reg in $regqrt {
  local r2dg = upper(substr("`reg'",1,2))
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^3 if _rowname=="employmt_par_${yrdiff}yrlg" | _rowname[_n-1]=="employmt_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="fixdasst_par_${yrdiff}yrlg" | _rowname[_n-1]=="fixdasst_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="turnover_par_${yrdiff}yrlg" | _rowname[_n-1]=="turnover_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="intmed_par_${yrdiff}yrlg" | _rowname[_n-1]=="intmed_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="liab_par_${yrdiff}yrlg" | _rowname[_n-1]=="liab_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^3 if _rowname=="employmt_par_${yrdiff}yrlg" | _rowname[_n-1]=="employmt_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="fixdasst_par_${yrdiff}yrlg" | _rowname[_n-1]=="fixdasst_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="turnover_par_${yrdiff}yrlg" | _rowname[_n-1]=="turnover_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="intmed_par_${yrdiff}yrlg" | _rowname[_n-1]=="intmed_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="liab_par_${yrdiff}yrlg" | _rowname[_n-1]=="liab_par_${yrdiff}yrlg"
  }
save "tex/`path'/dprobit_aerrr_tbl.dta", replace
matload dprobit_aerrr_tbl, p(tex/`path') over missing(.) dropall
est2tex dprobit_aerrr, replace dropall ready preserve mark(starse) p(tex/`path') fancy levels(90 95 99)
}

foreach path in "v6npfs/ptmanf-afmanf-frmunowage-cf" "v6npfs/ptmanf-afmanf-frmunowage-cf-poly2" {
est2extlbl, addto(selreg_aerrr) intex($rootdo/%stata/rowlbl-fdiselct) p(tex/`path') replace
use "tex/`path'/selreg_txt_tbl.dta", clear
foreach reg in $regagg {
  local r2dg = upper(substr("`reg'",1,2))
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^3 if _rowname=="employmt_par_${yrdiff}yrlg" | _rowname[_n-1]=="employmt_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="fixdasst_par_${yrdiff}yrlg" | _rowname[_n-1]=="fixdasst_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="turnover_par_${yrdiff}yrlg" | _rowname[_n-1]=="turnover_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="intmed_par_${yrdiff}yrlg" | _rowname[_n-1]=="intmed_par_${yrdiff}yrlg"
  qui capture replace `r2dg'${usexvar} = `r2dg'${usexvar}*10^9 if _rowname=="liab_par_${yrdiff}yrlg" | _rowname[_n-1]=="liab_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^3 if _rowname=="employmt_par_${yrdiff}yrlg" | _rowname[_n-1]=="employmt_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="fixdasst_par_${yrdiff}yrlg" | _rowname[_n-1]=="fixdasst_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="turnover_par_${yrdiff}yrlg" | _rowname[_n-1]=="turnover_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="intmed_par_${yrdiff}yrlg" | _rowname[_n-1]=="intmed_par_${yrdiff}yrlg"
  qui capture replace `r2dg'4 = `r2dg'4*10^9 if _rowname=="liab_par_${yrdiff}yrlg" | _rowname[_n-1]=="liab_par_${yrdiff}yrlg"
  }
save "tex/`path'/selreg_aerrr_tbl.dta", replace
matload selreg_aerrr_tbl, p(tex/`path') over missing(.) dropall
est2tex selreg_aerrr, replace dropall ready preserve mark(starse) p(tex/`path') fancy levels(90 95 99)
}


log close
cd "$root"
