*! version 1.0.2  11dec2008  by Marc Muendler muendler@ucsd.edu

version 8.2
cd "$rootslct"
clear
set matsize 400
set mem 400m
set more off

capture mkdir "$rootslct/tex/pop"
capture mkdir "$rootslct/tex/pop/pt$par-af$aff"  /* Directories not affected if they exist */

capture log close
log using "logs/unctad-ilo-comp-pt$par-af$aff.log", replace

local tlogyear 2000  /* reference year 2000 */
local tlogyr = substr("`tlogyear'",3,2)
local selyear = `tlogyear' - ${yrdiff}
local selyr = substr("`selyear'",3,2)

* external files
tempfile secfix isocntry naceconc iso3buba cntrgrpbem
global secfix "`secfix'"
use "$root/conc/sector-conc-nace", clear
sort buba_code
save `naceconc'
use "$root/conc/fdi-iso-country", clear
sort buba
compress
save `isocntry'
do "$dpref/#sector-definitions.do"
use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'
use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'

local share $share


* OECD-UNCTAD
*------------
* read-in variables in USD mio; transform to DEM mio
tempfile isoname unctad
use bubakey isoname using "$root/conc/country-table", clear
duplicates drop
drop if bubakey==. | isoname==""
replace isoname="Yemen, People's Democratic Republic of" if isoname=="Yemen, Democratic, People's Democratic Republic of"
order bubakey isoname
compress
duplicates tag bubakey, gen(_duplbuba)
sort bubakey
save `isoname'
use country using "$root/Xdata/undefl-outwfdi96-01-dem", clear
duplicates drop
rename country bubakey
sort bubakey
joinby bubakey using `isoname', unmatched(master) _merge(_merge)
qui count if _m~=3
if `r(N)'>0  STOP
drop _merge
sort isoname
save `isoname', replace
use isoname year aggsec infdi using "$root/countries/unctad-oecd-fdiagg", clear
sort year
merge year using "$root/outdata/usd-eur-exchr", nokeep
qui count if _m~=3
if `r(N)'>0  STOP
drop avg_cpdeum _merge
replace infdi = ( infdi / avg_usd_eur ) * 1.95583
label var infdi "Inward FDI stock [DEM mio]"
keep if year==`tlogyear'         // reference year only
keep if aggsec=="Manufacturing"  // manufacturing only
drop year aggsec avg_usd_eur
drop if infdi==. | infdi==0
sort isoname
save `unctad'
use `isoname'
merge isoname using `unctad'
tab isoname if _m==2
drop if infdi==. | _m==2
drop _m _duplbuba isoname
count  // only 61 countries with inward FDI information in manufacturing in 2000 remain
sort bubakey
qui count if bubakey==bubakey[_n-1]
if `r(N)'>0  STOP
sort bubakey
save `unctad', replace


* ILO
*----
tempfile isocode ilo
use bubakey isocode using "$root/conc/country-table", clear
duplicates drop
drop if bubakey==. | isocode==""
order bubakey isocode
compress
duplicates tag bubakey, gen(_duplbuba)
sort bubakey
save `isocode'
use country using "$root/Xdata/undefl-outwfdi96-01-dem", clear
duplicates drop
rename country bubakey
sort bubakey
joinby bubakey using `isocode', unmatched(master) _merge(_merge)
qui count if _m~=3
if `r(N)'>0  STOP
drop _merge
sort isocode
save `isocode', replace
use isocode year empl using "$root/countries/ilo-1998-2007", clear  // manufacturing only
keep if year==`tlogyear'    // reference year only
drop year
drop if empl==.
count  // only 73 countries with ILO employment information in manufacturing in 2000 remain
sort isocode
save `ilo'
use `isocode'
merge isocode using `ilo'
tab isocode if _m==2  // de (Germany), iq (Iraq), mr (Mauretania)
drop if empl==. | _m==2
drop _m _duplbuba isocode
count  // only 70 countries with ILO employment information in manufacturing in 2000 remain
sort bubakey
tab bubakey if bubakey==bubakey[_n-1]  // USA (Puerto Rico) requires aggregation
collapse (sum) empl, by(bubakey) fast
replace empl = empl*1000     // employment head count
rename empl iloempl
label var iloempl "Manufacturing Employment (ILO)"
sort bubakey
save `ilo', replace


* MiDi
*-----
* read-in variables in DEM thsd; transform to DEM mio
tempfile midi
use "$root/Xdata/undefl-outwfdi96-01-dem", clear
capture drop cntrygrp
encode cntrygrp_bem, gen(cntrygrp) label(cntrygrp)  // from %00/deflate-affils.do
capture gen str sec1 = ""
drop sec1
encode sec1_fix, gen(sec1) label(sec)  // from %00/deflate-affils.do
drop cntrygrp_fix cntrygrp_bem

* rename bg share
keep firmid affil2id year share sec1 sec2_fix country cntrygrp employmt dpu
order firmid affil2id year share sec1 sec2_fix country cntrygrp employmt dpu
sort firmid affil2id year
count

* transform to DEM mio
replace dpu = dpu/1000

* FROM #bemfiles.do
keep if year==`tlogyear'  // (| year==`selyear')
count
tab year

* FROM prep-parent-hostcntry-data-selct.do
keep if share>`share'
count
* country_grp definitions (as in swe-ger-conc.do)
foreach var in country {
    * tab `var'
    rename `var' bubakey  
    sort bubakey 
    merge bubakey using "$root/conc/cntry2bemgrp", nokeep
    count if _m~=3 & bubakey~=.
    if `r(N)' > 0 {
        disp as err "Incomplete country concordance"
        STOP
        }
    rename bubakey `var'
    rename cntrygrp_bem `var'grp_fix
    drop _merge
    }
rename countrygrp_fix cntrygrp_bem
label var cntrygrp_bem "Country group of affiliate"
sort firmid affil2id year
* sector and country resetting (similar to prep-summarize-affils.do)
do "$dpref/#sector-country-resetting.do"

rename country bubakey
qui do "$root/conc/enbubalo05.do"
label define enbubalo 0 `"Germany"', modify
label values bubakey enbubalo

keep if year==`tlogyear'

save `midi'


/* MARKET SHARE CALCULATIONS FOR MANUFACTURING PARENT AND MANUFACTURING AFFILIATE */
/*--------------------------------------------------------------------------------*/

use `midi', clear
* affiliate sector selection
if "$par" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$par" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "$aff" == "manf" {
  keep if sec2_aggbem>=2 & sec2_aggbem<=4
  }
if "$aff" == "nonmf" {
  drop if sec2_aggbem>=2 & sec2_aggbem<=4
  }
count

// merge OECD-UNCTAD data
sort bubakey
merge bubakey using `unctad', nokeep
tab _m
tab bubakey if _m==1
replace dpu=. if dpu<0  // not clear how to handle
replace dpu=. if _m==1  // no matching OECD-UNCTAD information, remove from MiDi for regional aggregation
drop _m
gen dpu_share = dpu/infdi
summ dpu_share
tab bubakey if dpu_share>.1 & dpu_share~=.

// merge ILO data
sort bubakey
merge bubakey using `ilo', nokeep
tab _m
tab bubakey if _m==1
replace employmt=. if _m==1  // no matching ILO information, remove from MiDi for regional aggregation
drop _m
gen empl_share = employmt/iloempl
summ empl_share
tab bubakey if empl_share>.02 & empl_share~=.

* FROM prep-translog-fdidata.do and prep-mvprobit-med-wagediff.do /* but retaining both years */
rename bubakey country
order firmid sec1_bem country year
sort country
merge country using `iso3buba', nokeep
tab _m
drop _m
sort country
merge country using `cntrgrpbem', nokeep
tab _m
drop _m
sort firmid year country
label var cntrybemgrp "Country group BEM"
qui do "$root/conc/secbem.do"
label values sec1_bem secbem

* Aggregation
preserve  // affiliate shares in foreign country FDI and labor markets
  collapse (mean) dpu_share empl_share (sd) sd_dpu_share=dpu_share sd_empl_share=empl_share (count) n_dpu_share=dpu_share n_empl_share=empl_share, by(cntrybemgrp) fast
  gen se_dpu_share = sd_dpu_share / sqrt(n_dpu_share)
  gen se_empl_share = sd_empl_share / sqrt(n_empl_share)
  mkmat dpu_share empl_share se_dpu_share se_empl_share n_dpu_share n_empl_share, matrix(_tmp)
  mat rownames _tmp = $regagg
  list cntry dpu_share empl_share
  mat mktshares_b = _tmp[1...,1..2] '
  mat mktshares_se = _tmp[1...,3..4] '
  mat mktshares_e = _tmp[1...,5..6] '
  est2tex mktshares, fancy p(tex/pop/pt$par-af$aff) replace dropall
restore, preserve  // parent-firm shares in foreign country FDI and labor markets
  collapse (sum) dpu_share empl_share, by(firmid country cntrybemgrp) fast
  collapse (mean) dpu_share empl_share (sd) sd_dpu_share=dpu_share sd_empl_share=empl_share (count) n_dpu_share=dpu_share n_empl_share=empl_share, by(cntrybemgrp) fast
  gen se_dpu_share = sd_dpu_share / sqrt(n_dpu_share)
  gen se_empl_share = sd_empl_share / sqrt(n_empl_share)
  mkmat dpu_share empl_share se_dpu_share se_empl_share n_dpu_share n_empl_share, matrix(_tmp)
  mat rownames _tmp = $regagg
  list cntry dpu_share empl_share
  mat mktshares_frm_b = _tmp[1...,1..2] '
  mat mktshares_frm_se = _tmp[1...,3..4] '
  mat mktshares_frm_e = _tmp[1...,5..6] '
  est2tex mktshares_frm, fancy p(tex/pop/pt$par-af$aff) replace dropall
restore, preserve  // parent-firm shares in foreign country FDI and labor markets
  collapse (sum) dpu_share empl_share, by(country cntrybemgrp) fast
  collapse (mean) dpu_share empl_share (sd) sd_dpu_share=dpu_share sd_empl_share=empl_share (count) n_dpu_share=dpu_share n_empl_share=empl_share, by(cntrybemgrp) fast
  gen se_dpu_share = sd_dpu_share / sqrt(n_dpu_share)
  gen se_empl_share = sd_empl_share / sqrt(n_empl_share)
  mkmat dpu_share empl_share se_dpu_share se_empl_share n_dpu_share n_empl_share, matrix(_tmp)
  mat rownames _tmp = $regagg
  list cntry dpu_share empl_share
  mat mktshares_ger_b = _tmp[1...,1..2] '
  mat mktshares_ger_se = _tmp[1...,3..4] '
  mat mktshares_ger_e = _tmp[1...,5..6] '
  est2tex mktshares_ger, fancy p(tex/pop/pt$par-af$aff) replace dropall
restore

foreach type in b se e {
  mat mktshares_all_`type' = mktshares_`type' \ mktshares_frm_`type' \ mktshares_ger_`type'
  mat roweq mktshares_all_`type' = affil affil mne mne allmne allmne
  }
est2tex mktshares_all, fancy p(tex/pop/pt$par-af$aff) replace dropall


/* SECTOR CROSS-TABULATIONS FOR MANUFACTURING PARENTS AND ANY AFFILIATES */
/*-----------------------------------------------------------------------*/

local par = "manf" /* Keep manufacturing parents  */
local aff = "all"  /* Keep any affiliate */

capture mkdir "$rootslct/tex/pop"
capture mkdir "$rootslct/tex/pop/pt`par'-af`aff'"  /* Directories not affected if they exist */

use `midi', clear
* affiliate sector selection
if "`par'" == "manf" {
  keep if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "`par'" == "nonmf" {
  drop if sec1_aggbem>=2 & sec1_aggbem<=4
  }
if "`aff'" == "manf" {
  keep if sec2_aggbem>=2 & sec2_aggbem<=4
  }
if "`aff'" == "nonmf" {
  drop if sec2_aggbem>=2 & sec2_aggbem<=4
  }
count

// Affiliate counts by sector
preserve
* table sec2_aggbem sec1_aggbem, contents(count affil2id)
tabl2tex affil2id, type(count) row(sec2_aggbem) col(sec1_aggbem) path(tex/pop/pt`par'-af`aff') name(aggcnt_affil) fancy replace over thousep
restore, preserve
* table sec2_bem sec1_bem, contents(count affil2id)
tabl2tex affil2id, type(count) row(sec2_bem) col(sec1_bem) path(tex/pop/pt`par'-af`aff') name(cnt_affil) fancy replace over thousep
restore, preserve
* table sec2_aggbem sec1_aggbem if cntrybemgrp==1, contents(count affil2id)
tabl2tex affil2id if cntrybemgrp==1, type(count) row(sec2_aggbem) col(sec1_aggbem) path(tex/pop/pt`par'-af`aff') name(aggcnt_affil_cee) fancy replace over thousep
restore, preserve
* table sec2_bem sec1_bem if cntrybemgrp==1, contents(count affil2id)
tabl2tex affil2id if cntrybemgrp==1, type(count) row(sec2_bem) col(sec1_bem) path(tex/pop/pt`par'-af`aff') name(cnt_affil_cee) fancy replace over thousep

// Employment counts by sector
restore, preserve
* table sec2_aggbem sec1_aggbem, contents(sum employmt)
tabl2tex affil2id, type(count) row(sec2_aggbem) col(sec1_aggbem) path(tex/pop/pt`par'-af`aff') name(aggsum_empl) fancy replace over thousep
restore, preserve
* table sec2_bem sec1_bem, contents(sum employmt)
tabl2tex affil2id, type(count) row(sec2_bem) col(sec1_bem) path(tex/pop/pt`par'-af`aff') name(sum_empl) fancy replace over thousep
restore, preserve
* table sec2_aggbem sec1_aggbem if cntrybemgrp==1, contents(sum employmt)
tabl2tex affil2id if cntrybemgrp==1, type(count) row(sec2_aggbem) col(sec1_aggbem) path(tex/pop/pt`par'-af`aff') name(aggsum_empl_cee) fancy replace over thousep
restore, preserve
* table sec2_bem sec1_bem if cntrybemgrp==1, contents(sum employmt)
tabl2tex affil2id if cntrybemgrp==1, type(count) row(sec2_bem) col(sec1_bem) path(tex/pop/pt`par'-af`aff') name(sum_empl_cee) fancy replace over thousep
restore

log close
cd "$root"
