*! version 1.1.2  15sep2008  by Marc Muendler  muendler@ucsd.edu

version 8.2
clear
set memory 500m
set more off

cd "$rootslct"

capture log close
log using "logs/prep-parent-hostregion-data-selct-pt$par-af$aff-allyrs.log", replace

/* External data preperation */
/*---------------------------*/

* aggregate regions
tempfile cntrgrpbem
use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'


/* Region-level exposure measures */
/*--------------------------------*/

use "$rootslct/Xdata/data-parent-hostcntry-pt$par-af$aff-allyrs", clear

order firmid ustan nace1 sec1_bem country year
sort country
merge country using `cntrgrpbem', nokeep
tab _m
keep firmid ustan country cntrygrp_bem nace1 sec1_bem sec1_aggbem year employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par turnover_ppp employmt wb_ppp fixdasst_ppp numaffil
order firmid ustan country cntrygrp_bem nace1 sec1_bem sec1_aggbem year employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par turnover_ppp employmt wb_ppp fixdasst_ppp numaffil

* apply BEM cntrybemgrp definitions
/*-----------------------
 WEU: EMU (3), OWE (6);
 OIN: OIN (5);
 CEE: CEE (2); 
 DEV: APC (1), ODV (4) and RCA (7)
 --------------------------------------------*/
tab cntrygrp_bem
gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
label var cntrybemgrp "Country group BEM"
drop cntrygrp_bem
collapse (sum) turnover_ppp employmt wb_ppp fixdasst_ppp numaffil, by(firmid ustan cntrybemgrp nace1 sec1_bem sec1_aggbem year employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par)
preserve
  tempfile parvars
  keep firmid ustan nace1 sec1_bem sec1_aggbem year employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par
  duplicates drop
  sort firmid year
  save `parvars'
restore
drop ustan nace1 sec1_bem sec1_aggbem employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par
foreach var in turnover wb fixdasst employmt numaffil {
  rename `var' `var'_
  }

reshape wide turnover employmt wb fixdasst numaffil, i(firmid year) j(cntrybemgrp) string
foreach reg in $regagg {
  label var turnover_`reg' "Turnover [ppp] `reg'"
  label var employmt_`reg' "Employment `reg'"
  label var wb_`reg'       "Total wage bill `reg'"
  label var fixdasst_`reg' "Fixed assets [quasi ppp] `reg'"
  label var numaffil_`reg' "Affiliates count `reg'"
  foreach var in turnover employmt wb fixdasst numaffil {
    replace `var'_`reg' = 0 if `var'_`reg'==.
    }
  }
sort firmid year
merge firmid year using `parvars'
qui count if _m~=3
if `r(N)'>0  STOP  // matching error
drop _m
sort firmid year
order firmid year ustan nace1 sec1_bem sec1_aggbem employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par employmt* wb* turnover* fixdasst* numaffil*


/* Finalize */
/*----------*/

compress
sort firmid year
save "Xdata/data-parent-hostregion-pt$par-af$aff-allyrs", replace

log close
cd "$root"
