*! version 1.3.7  15jan2009  by Marc Muendler  muendler@ucsd.edu
*! version 2.0.1  15jun2009  by Marc Muendler  muendler@ucsd.edu

clear
set memory 400m
set matsize 400
set more off
capture log close

cd "$rootslct"

log using "logs/translog-plainreg-bstrap-pt$par-af$aff-$waglvl.log", replace

local reps = $reps
* ISUR with maximum number of iterations to avert non-convergence under bootstraps

local usemissg 1

#delimit ;

adopath + "$root/%stata/ado"; 


/* estimation routine */
/*--------------------*/
capture program drop sure1stp;
program define sure1stp;
  syntax [namelist];

  foreach reg in $regagg {;
    local r2dg = substr("`reg'",1,2);
    local namelist`r2dg' "";
    tokenize `namelist';
    local num :  word count `namelist';
    forvalues i = 1/`num' {;
      if substr("``i''",1,5)~="nofdi"  local var = "cf`r2dg'_" + subinstr("``i''","cf_","",.);
      else                             local var = "``i''";
      local namelist`r2dg' "`namelist`r2dg'' `var'";
      };
    };

  * one step: seemingly unrelated regressions;
  sureg (sCE: yCE = `namelistCE' cfCE, nocons)
        (sDE: yDE = `namelistDE' cfDE, nocons)
        (sOI: yOI = `namelistOI' cfOI, nocons)
        (sWE: yWE = `namelistWE' cfWE, nocons)
  /*    , constraints(2 3 4 6 7 9 12 13 14 15) */
        , isur iterate($maxiter);
  *     (sHO: yHO = `namelistHO' cfHO, nocons); /* left-out equation */

  local collbl "wHO wCE wDE wOI wWE";
  local rowlbl "sCE sDE sOI sWE";
  mat coefmat = J(5,5,.);
  local i = 1;
  foreach lreg in `rowlbl' {;
    local eqlbl = substr("`lreg'",2,2);
    local i = `i' + 1;
    local j = 0;
    foreach wreg in `collbl'{;
      local j = `j' + 1;
      mat coefmat[`i',`j'] = _b[`lreg':cf`eqlbl'_`wreg'];
      };
    mat coefmat[1,`i'] = _b[`lreg':cf`eqlbl'_wHO];
    };
  mat coefmat[1,1] = - (coefmat[2,1] + coefmat[3,1] + coefmat[4,1] + coefmat[5,1]);
  local rowlbl "sHO `rowlbl'";
  matname coefmat `collbl', columns(1..5) explicit;
  matname coefmat `rowlbl', rows(1..5) explicit;

  calcelast;
end;


/* elasticity posting */
/*--------------------*/
capture program drop calcelast;
program define calcelast, rclass;
  foreach reg in CE DE OI WE {;
    * qui predict double shat`reg', equation(s`reg') xb, if e(sample);
    qui gen double shat`reg' = s`reg';
    };
  qui gen double shatHO = sHO;
  collapse (mean) shatHO shatCE shatDE shatOI shatWE if e(sample), fast;
  mkmat shatHO shatCE shatDE shatOI shatWE, matrix(Tmat);  /* Tmat to be transposed to a column vector next */
  matname Tmat theta, rows(1) explicit;
  mat Tmat = Tmat';  /* Tmat transposed to a column vector */
  mat Tsqmat = Tmat * Tmat';

  * Calculate cross-price elasticities matrix at intensive margin;
  mat IntElast = coefmat + Tsqmat;
  forvalues r = 2/5 {; /* Fill lower-echelon entries */
  local maxcol = `r'-1;
    forvalues m = 1/`maxcol' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues m = 2/5 {; /* Fill upper-echelon entries */
  local maxrow = `m'-1;
    forvalues r = 1/`maxrow' {;
      mat IntElast[`r',`m'] = IntElast[`r',`m'] / Tmat[`r',1];
      };
    };
  forvalues r = 1/5 {;  /* Fill diagonal entries */
      mat IntElast[`r',`r'] = IntElast[`r',`r'] / Tmat[`r',1] - 1;
    };
  * matname IntElast sHO sCE sDE sOI sWE, rows(1..5) explicit;
  * matname IntElast wHO wCE wDE wOI wWE, columns(1..5) explicit;
  * mat list IntElast;
  * disp;

  mat TotElast = IntElast;
  mat ExtElast = J(5,5,-999);
  mat rowname ExtElast = `rownames';
  mat colname ExtElast = `rownames';

  * assemble elasticity estimate in one vector;
  foreach elsttyp in Int Ext Tot {;
    local cols = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + colsof(`elsttyp'Elast);
    mat b`elsttyp'Elast = J(1,`cols',.);
    local i = 0;
    foreach regi in HO CE DE OI WE {;
      local i = `i' + 1;
      local j = 0;
      foreach regj in HO CE DE OI WE {;
        local j = `j' + 1;
        local col = (`i'-1)*colsof(`elsttyp'Elast) + `j';
        mat b`elsttyp'Elast[1,`col'] = `elsttyp'Elast[`i',`j'];
        matname b`elsttyp'Elast `elsttyp'_l`regi'_w`regj', columns(`col') explicit;
        };
      local thetacol = rowsof(`elsttyp'Elast) * colsof(`elsttyp'Elast) + `i';
      qui summ shat`regi', meanonly;
      mat b`elsttyp'Elast[1,`thetacol'] = `r(mean)';
      matname b`elsttyp'Elast `elsttyp'_s`regi'mean, columns(`thetacol') explicit;
      };
    };
  mat bElast = bTotElast , bExtElast , bIntElast;

  local colnams : colfullnames bElast;
  tempname pseudocov;
  matrix `pseudocov' = -999*I(`cols'*3);
  matrix colnames `pseudocov' = `colnams';
  matrix rownames `pseudocov' = `colnams';

  ereturn post bElast `pseudocov';

end;


/* define X-equation restrictions */
/*--------------------------------*/

* constraint define  1 [sCE]cfCE_wHO = [sHO]cfHO_wCE;
  constraint define  2 [sCE]cfCE_wDE = [sDE]cfDE_wCE;
  constraint define  3 [sCE]cfCE_wOI = [sOI]cfOI_wCE;
  constraint define  4 [sCE]cfCE_wWE = [sWE]cfWE_wCE;
* constraint define  5 [sDE]cfDE_wHO = [sHO]cfHO_wDE;
  constraint define  6 [sDE]cfDE_wOI = [sOI]cfOI_wDE;
  constraint define  7 [sDE]cfDE_wWE = [sWE]cfWE_wDE;
* constraint define  8 [sOI]cfOI_wHO = [sHO]cfHO_wOI;
  constraint define  9 [sOI]cfOI_wWE = [sWE]cfWE_wOI;
* constraint define 10 [sWE]cfWE_wHO = [sHO]cfHO_wWE;
* constraint define 11 [sHO]cfHO_wHO + [sHO]cfHO_wCE + [sHO]cfHO_wDE + [sHO]cfHO_wOI + [sHO]cfHO_wWE = 0;
  constraint define 12 [sCE]cfCE_wHO + [sCE]cfCE_wCE + [sCE]cfCE_wDE + [sCE]cfCE_wOI + [sCE]cfCE_wWE = 0;
  constraint define 13 [sDE]cfDE_wHO + [sDE]cfDE_wCE + [sDE]cfDE_wDE + [sDE]cfDE_wOI + [sDE]cfDE_wWE = 0;
  constraint define 14 [sOI]cfOI_wHO + [sOI]cfOI_wCE + [sOI]cfOI_wDE + [sOI]cfOI_wOI + [sOI]cfOI_wWE = 0;
  constraint define 15 [sWE]cfWE_wHO + [sWE]cfWE_wCE + [sWE]cfWE_wDE + [sWE]cfWE_wOI + [sWE]cfWE_wWE = 0;

/* With 5 regions, there are (5*5-5)/2=10 symmetry restrictions in principle. 
   However, one equation drops due to further cross-equation constraints, 
   only 6 of the symmetry restrictions are needed.
   Similarly, only 4 of the 5 restrictions on wage parameter sums are needed. */


/* data and main loop */
/*--------------------*/

capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf";
capture mkdir "$rootslct/estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg'";

use "$rootslct/Xdata/mneid-forbstrap`usemissg'-$waglvl-pt$par-af$aff-cf-allyrs", clear;
drop mCE dltaCE mDE dltaDE mOI dltaOI mWE dltaWE;


/* Bootstrap SUR under restrictions */
/*----------------------------------*/

* sure1stp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE nofdiCE nofdiDE nofdiOI nofdiWE;
* mat bElast = e(b);
* mat list bElast;
local nofdi "nofdiCE nofdiDE nofdiOI nofdiWE";

* keep mneid year sec1_bem yHO yCE yDE yOI yWE sHO sCE sDE sOI sWE ${paruse} cf??_wHO cf??_wCE cf??_wDE cf??_wOI cf??_wWE cf??_tHO cf??_tCE cf??_tDE cf??_tOI cf??_tWE cf??_kHO cf??_kCE cf??_kDE cf??_kOI cf??_kWE `nofdi' cfHO cfCE cfDE cfOI cfWE;
* sure1stp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE `nofdi';

bootstrap "sure1stp cf_wHO cf_wCE cf_wDE cf_wOI cf_wWE cf_tHO cf_tCE cf_tDE cf_tOI cf_tWE cf_kHO cf_kCE cf_kDE cf_kOI cf_kWE `nofdi'" _b, 
        reps(`reps') double saving(estmat/v6fs/pt$par-af$aff-$waglvl-plainreg-cf/translog`usemissg'/elast`usemissg'_bstrap) every(50) dots replace;

mat drop coefmat TotElast ExtElast IntElast bTotElast bExtElast bIntElast Tmat Tsqmat;

capture program drop sure1stp;
capture program drop calcelast;


log close;
cd "$root";
