*! version 1.1.3  22oct2008  by Marc Muendler  muendler@ucsd.edu

version 8.2
clear
set memory 400m
set matsize 400
set more off
capture log close

capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf"
capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf/cafege"

cd "$rootslct"
log using "logs/xtivreg-translog-smpl-pt$par-af$aff-allyrs.log", replace

mat drop _all

adopath + "$root/%stata/ado"


/* region-level IVs and outside margin */
/*-------------------------------------*/

* WTF IVs (one-year lags)
tempfile wtfprox lgwtfprx wtf37
use "$root/trade/wtf-fdiproxies-1989-2000", clear  //  ===in USD billion, US-CPI deflated to base year 1998===
* transform to ===EUR million, deflated to base year 1998===
local idvars "nace11 year"
unab allvars : *
unab relvars : rdl1_*
unab logvars : ln_*
local remvars : list idvars | relvars 
local remvars : list remvars | logvars
local genvars : list allvars - remvars
foreach v of local genvars {
  replace `v' = `v' * 1000 / 1.17499  // from wae 400, bil_jhr 1998, bil_mo 12 in indata/euro-kurse.dta
  }
foreach v of local logvars {
  replace `v' = `v' + log(1000) - log(1.17499)  // from wae 400, bil_jhr 1998, bil_mo 12 in indata/euro-kurse.dta
  }
drop dl1_* rdl1_* ln_*
rename nace11 nace1
preserve
  collapse (mean) vfdi* hfdi* expfdi*, by(year)  // use annual mean of all sectors for sector 37
  gen byte nace1 = 37
  sort nace1 year
  save `wtf37'
restore
append using `wtf37'
sort nace1 year
save `wtfprox'
replace year = year + $yrdiff  // for $yrdiff-year lags (level regressions)
foreach var in vfdi_oecd hfdi_oecd expfdi {
  egen `var'_DEV = rsum(`var'_APC `var'_ODV `var'_RCA)
  egen `var'_WEU = rsum(`var'_EMU `var'_OWE)
  drop `var'_APC `var'_EMU `var'_ODV `var'_OWE `var'_RCA
  }
label var vfdi_oecd_DEV "DEV Exports to OECD (excl. D)"
label var hfdi_oecd_DEV "DEV Imports from OECD (excl. D)"
label var expfdi_DEV "DEV Exp. to neighbors (excl. D)"
label var vfdi_oecd_WEU "WEU Exports to OECD (excl. D)"
label var hfdi_oecd_WEU "WEU Imports from OECD (excl. D)"
label var expfdi_WEU "WEU Exp. to neighbors (excl. D)"
keep nace1 year vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
order nace1 year vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
sort nace1 year
save `lgwtfprx'  // ===in EUR million, deflated to base year 1998===

* German trade at the outside margin
tempfile iso3buba cntrgrpbem lgimpinp
use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'
use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'
forvalues year = 1997/2002 {
  tempfile impinp`year'
  use "$root/trade/ger-impinp-exp-secbem-ctrygrp-`year'.dta", clear  //  ===in EUR 1,000, D-CPI deflated to base year 2000===
  * transform to ===EUR million, base year 1998===
  replace export = export / ( 1000 * 1.020494 )  // deflator based on cumcpi=cumcpi[_n-1]*(1+dcpi) using outdata/deflators-2005.dta
  replace import = import / ( 1000 * 1.020494 )  // deflator based on cumcpi=cumcpi[_n-1]*(1+dcpi) using outdata/deflators-2005.dta
  replace impinp = impinp / ( 1000 * 1.020494 )  // deflator based on cumcpi=cumcpi[_n-1]*(1+dcpi) using outdata/deflators-2005.dta
  replace buba=11 if buba==23
  drop if buba==950 | buba==958  // 950 `"Schiffs- und Luftfahrzeugbedarf"', 958 `"Nicht ermittelte Lnder und Gebiete"'
  rename buba country
  sort country
  merge country using `cntrgrpbem', nokeep
  qui count if _m~=3
  if `r(N)'>0  STOP  // mismatched country information
  drop _m
  * country group resetting as in %40/sector-country-resetting.do
  gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
  replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
  replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
  replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
  label var cntrybemgrp "Country group"
  collapse (sum) export import impinp, by(nace11_code cntrybemgrp)
  label var export "Exports (Mio EUR, defl. 1998=1)"
  label var import "Imports (Mio EUR, defl. 1998=1)"
  label var impinp "Imp. inputs (Mio EUR, dfl. 1998=1)"
  foreach var in export import impinp {
    rename `var' `var'_
    }
  reshape wide export_ import_ impinp_, i(nace11_code) j(cntrybemgrp) string
  foreach reg of global regagg {
    label var export_`reg' "Exports `reg' (Mio EUR 1998=1)"
    label var import_`reg' "Imports `reg' (Mio EUR 1998=1)"
    label var impinp_`reg' "Imp. inputs `reg' (Mio EUR 1998=1)"
    }
  gen int year = `year' - 1
  label var year "Calendar year"
  sort nace11_code year
  save `impinp`year''
  }
use `impinp1997'
forvalues year = 1998/2002 {
  append using `impinp`year''
  }
rename nace11_code nace1
sort nace1 year
save `lgimpinp'

  
/* employment level data */
/*-----------------------*/

tempfile empldata
use "Xdata/data-parent-hostregion-pt$par-af$aff-allyrs", clear
gen prft_eqty_par = profits_par/equity_par
label var prft_eqty_par "Profits/equity parent"
gen byte ind_exp_par = (exports_par>0 & exports_par~=.)
label var ind_exp_par "Indic.: Exports parent"
gen byte _mcmpvar = .
gen byte _mwage = .
order firmid year ustan nace1 sec1_bem sec1_aggbem employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par prft_eqty_par ind_exp_par
foreach year in 1996 1997 1998 1999 2000 2001 {
  sort firmid year
  merge firmid year using "Xdata/mneid-cafege-competitor-exposure-`year'-$waglvl-pt$par-af$aff", update
  drop if firmid==0
  replace _mcmpvar = _merge if _merge==3 | _merge==4
  drop _merge
  sort firmid year
  merge firmid year using "Xdata/mneid-cafege-wages-`year'-$waglvl", update
  replace _mwage = _merge if _merge==3 | _merge==4
  drop _merge
  }
tab _mcmpvar
qui count if _mcmpvar ~=3 & _mcmpvar ~=4
if `r(N)'>0  STOP  // matching error
drop _mcmpvar
tab _mwage
qui count if _mwage ~=3 & _mwage ~=4 & _mwage~=.
if `r(N)'>0  STOP  // matching error
drop _mwage

sort nace1 year
merge nace1 year using `lgwtfprx', nokeep
qui count if _merge ~=3
if `r(N)'>0  STOP  // matching error
drop _m

sort nace1 year
merge nace1 year using `lgimpinp', nokeep
qui count if _merge ~=3
if `r(N)'>0  STOP  // matching error
drop _m

table nace1 year, c(mean employmt_par)
table nace1 year, c(mean employmt_CEE)
table nace1 year, c(mean cmpt_employmt_CEE)
table nace1 year, c(mean w_CEE)
drop if nace1==37  // remove sector with scattered observations

sort firmid year
save `empldata'


/* link to translog (Heckman correction) data */
/*--------------------------------------------*/
* code similar to translog-selct-2stp-cf.do

foreach tlogyear in 1998 1999 2000 2001 {

tempfile mnes`tlogyear'
local tlogyr = substr("`tlogyear'",3,2)
local selyear = `tlogyear' - ${yrdiff}
local selyr = substr("`selyear'",3,2)

tempfile popinfo
use if year==`tlogyear' using "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs", clear
keep mneid iCEnow iDEnow iOInow iWEnow iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg
sort mneid
compress
save `popinfo'

* w_othr
use if year==`tlogyear' using `empldata', clear
drop year profits_par wb_* fixdasst_* assettot_* cmpt_wb_* cmpt_fixdasst_* numaffil_* w_*
rename firmid mneid
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-`selyear'-costothr-$waglvl-pt$par-af$aff"
drop s_othr_* k_othr_* t_othr_* l_othr_* wb_othr_*
tab _merge  // note: _m==2 b/c universe firms in mneid-outwfdi-ustan but only sample firms in `empldata'
foreach reg in $regagg {
  qui gen _avg_w_`reg' = w_othr_`reg' if mneid==0 /* market average (mneid==0 in using data) */
  qui egen _rpl_w_`reg' = max(_avg_w_`reg')
  qui replace w_othr_`reg' = _rpl_w_`reg' if w_othr_`reg'==. /* replace missing competitor info with market average (mneid==0 in using data) */
  drop _avg_w_`reg' _rpl_w_`reg'
  }
drop if _m==2
drop _merge

* past presence indicators
sort mneid
merge mneid using `popinfo', nokeep
tab _m
drop _m

sort mneid
gen year = `tlogyear'
label var year "Year (production, selection: -$yrdiff)"

order mneid year
save `mnes`tlogyear''

}  /* close `tlogyear' loop */

use `mnes1998'
forvalues tlogyear = 1999/2001 {
  append using `mnes`tlogyear''
  }
sort mneid year
compress

* variable resetting
rename mneid firmid
tabulate year, generate(indyr)
drop indyr1  // omitted year
tsset, clear

* LOG TRANSFORMATION

* unab outmarg : export_??? import_??? impinp_???
* unab ivs :  vfdi_oecd_??? hfdi_oecd_??? expfdi_???
* foreach var in employmt_par equity_par liab_par `outmarg' employmt_CEE employmt_DEV employmt_OIN employmt_WEU `ivs' {
*   replace `var' = log(`var') if `var'>0 & `var'~=.
*   * replace `var' = 0 if `var'==0 & `var'~=.
*   }

* INTERACTED INSTRUMENTS

gen ia_vCEE = iCE2yrlg * vfdi_oecd_CEE
gen ia_vDEV = iDE2yrlg * vfdi_oecd_DEV
gen ia_vOIN = iOI2yrlg * vfdi_oecd_OIN
gen ia_vWEU = iWE2yrlg * vfdi_oecd_WEU
label var ia_vCEE "iCE2yrlg * vfdi_oecd_CEE"
label var ia_vDEV "iDE2yrlg * vfdi_oecd_DEV"
label var ia_vOIN "iOI2yrlg * vfdi_oecd_OIN"
label var ia_vWEU "iWE2yrlg * vfdi_oecd_WEU"

gen ia_wCEE = iCE2yrlg * w_othr_CEE
gen ia_wDEV = iDE2yrlg * w_othr_DEV
gen ia_wOIN = iOI2yrlg * w_othr_OIN
gen ia_wWEU = iWE2yrlg * w_othr_WEU
label var ia_wCEE "iCE2yrlg * w_othr_CEE"
label var ia_wDEV "iDE2yrlg * w_othr_DEV"
label var ia_wOIN "iOI2yrlg * w_othr_OIN"
label var ia_wWEU "iWE2yrlg * w_othr_WEU"


/* LEVEL REGRESSIONS, CONDITIONAL ON PAST PRESENCE */
desc

* employment, OLS and 2SLS, 4 IVs only, no cmpt_employmt

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg iCEnow iDEnow iOInow iWEnow employmt_CEE employmt_DEV employmt_OIN employmt_WEU export_??? import_??? impinp_???
est2vec iv_tlgi_4iv_empl, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_empl)
est2vec iv_tlgi_4iv_empl, r(F p df df_r rank chi2) name(ols_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? (iCEnow iDEnow iOInow iWEnow employmt_CEE employmt_DEV employmt_OIN employmt_WEU = vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU)
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(iv_tlgi_4iv_empl_now)
est store ivsonly
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(iv_tlgi_4iv_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? (iCEnow iDEnow iOInow iWEnow employmt_CEE employmt_DEV employmt_OIN employmt_WEU = vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(iv_tlgi_4iv_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(iv_tlgi_4iv_empl)

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? employmt_CEE employmt_DEV employmt_OIN employmt_WEU indyr*
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtyr_empl_noext)
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtyr_empl_noext)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU = ia_wCEE ia_wDEV ia_wOIN ia_wWEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtivyr_empl_iaw_noext)
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtivyr_empl_iaw_noext)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU = vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU)
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtivyr_empl_now_noext)
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtivyr_empl_now_noext)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU = vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtivyr_empl_noext)
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtivyr_empl_noext)

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? iCEnow iDEnow iOInow iWEnow employmt_CEE employmt_DEV employmt_OIN employmt_WEU indyr*
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtyr_empl)
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtyr_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? indyr* (iCEnow iDEnow iOInow iWEnow employmt_CEE employmt_DEV employmt_OIN employmt_WEU = ia_wCEE ia_wDEV ia_wOIN ia_wWEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtivyr_empl_iaw)
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtivyr_empl_iaw)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? indyr* (iCEnow iDEnow iOInow iWEnow employmt_CEE employmt_DEV employmt_OIN employmt_WEU = vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU)
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtivyr_empl_now)
est store ivsonly
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtivyr_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg export_??? import_??? impinp_??? indyr* (iCEnow iDEnow iOInow iWEnow employmt_CEE employmt_DEV employmt_OIN employmt_WEU = vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_tlgi_4iv_empl, addto(iv_tlgi_4iv_empl) name(xtivyr_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(xtivyr_empl)

foreach reg in $regagg {
  local r2dgt = substr("`reg'",1,2)
  reg employmt_`reg' vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl
  test vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU
  est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(iv1_empl_`reg')
  reg i`r2dgt'now vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl
  test vfdi_oecd_CEE vfdi_oecd_DEV vfdi_oecd_OIN vfdi_oecd_WEU ia_vCEE ia_vDEV ia_vOIN ia_vWEU
  est2vec iv_tlgi_4iv_empl, raddto(iv_tlgi_4iv_empl) name(iv1_i`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU if indsmpl, c(mean sd N p50) name(summ_iv_tlgi_4iv_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* employment, OLS and 2SLS

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU
est2vec iv_tlgi_empl, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_empl)
est2vec iv_tlgi_empl, r(F p df df_r rank chi2) name(ols_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlgi_empl, addto(iv_tlgi_empl) name(iv_tlgi_empl_now)
est store ivsonly
est2vec iv_tlgi_empl, raddto(iv_tlgi_empl) name(iv_tlgi_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlgi_empl, addto(iv_tlgi_empl) name(iv_tlgi_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlgi_empl, raddto(iv_tlgi_empl) name(iv_tlgi_empl)

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*
est2vec iv_tlgi_empl, addto(iv_tlgi_empl) name(xtyr_empl)
est2vec iv_tlgi_empl, raddto(iv_tlgi_empl) name(xtyr_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlgi_empl, addto(iv_tlgi_empl) name(xtivyr_empl_now)
est store ivsonly
est2vec iv_tlgi_empl, raddto(iv_tlgi_empl) name(xtivyr_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_tlgi_empl, addto(iv_tlgi_empl) name(xtivyr_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlgi_empl, raddto(iv_tlgi_empl) name(xtivyr_empl)

foreach reg in $regagg {
  reg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec iv_tlgi_empl, raddto(iv_tlgi_empl) name(iv1_empl_`reg')
  reg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
  est2vec iv_tlgi_empl, raddto(iv_tlgi_empl) name(iv1_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_iv_tlgi_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, OLS and 2SLS

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU
est2vec iv_tlgi_turnov, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_turnov)
est2vec iv_tlgi_turnov, r(F p df df_r rank chi2) name(ols_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlgi_turnov, addto(iv_tlgi_turnov) name(iv_tlgi_turnov_now)
est store ivsonly
est2vec iv_tlgi_turnov, raddto(iv_tlgi_turnov) name(iv_tlgi_turnov_now)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlgi_turnov, addto(iv_tlgi_turnov) name(iv_tlgi_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlgi_turnov, raddto(iv_tlgi_turnov) name(iv_tlgi_turnov)

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*
est2vec iv_tlgi_turnov, addto(iv_tlgi_turnov) name(xtyr_turnov)
est2vec iv_tlgi_turnov, raddto(iv_tlgi_turnov) name(xtyr_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlgi_turnov, addto(iv_tlgi_turnov) name(xtivyr_turnov_now)
est store ivsonly
est2vec iv_tlgi_turnov, raddto(iv_tlgi_turnov) name(xtivyr_turnov_now)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_tlgi_turnov, addto(iv_tlgi_turnov) name(xtivyr_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlgi_turnov, raddto(iv_tlgi_turnov) name(xtivyr_turnov)

foreach reg in $regagg {
  reg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec iv_tlgi_turnov, raddto(iv_tlgi_turnov) name(iv1_turnov_`reg')
  reg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec iv_tlgi_turnov, raddto(iv_tlgi_turnov) name(iv1_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_iv_tlgi_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* employment, sector (sec1_bem) level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_tlgi_empl, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_empl)
est2vec xtivsec_tlgi_empl, r(F p df df_r rank chi2) name(xtsec_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
est2vec xtivsec_tlgi_empl, addto(xtivsec_tlgi_empl) name(xtivsec_tlgi_empl_now)
est store ivsonly
est2vec xtivsec_tlgi_empl, raddto(xtivsec_tlgi_empl) name(xtivsec_tlgi_emp_now)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_tlgi_empl, addto(xtivsec_tlgi_empl) name(xtivsec_tlgi_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivsec_tlgi_empl, raddto(xtivsec_tlgi_empl) name(xtivsec_tlgi_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlgi_empl, raddto(xtivsec_tlgi_empl) name(xt1sec_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlgi_empl, raddto(xtivsec_tlgi_empl) name(xt1sec_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_tlgi_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, sector (sec1_bem) level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_tlgi_turnov, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_turnov)
est2vec xtivsec_tlgi_turnov, r(F p df df_r rank chi2) name(xtsec_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
est2vec xtivsec_tlgi_turnov, addto(xtivsec_tlgi_turnov) name(xtivsec_tlgi_turnov_now)
est store ivsonly
est2vec xtivsec_tlgi_turnov, raddto(xtivsec_tlgi_turnov) name(xtivsec_tlgi_turnov_now)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_tlgi_turnov, addto(xtivsec_tlgi_turnov) name(xtivsec_tlgi_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivsec_tlgi_turnov, raddto(xtivsec_tlgi_turnov) name(xtivsec_tlgi_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlgi_turnov, raddto(xtivsec_tlgi_turnov) name(xt1sec_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlgi_turnov, raddto(xtivsec_tlgi_turnov) name(xt1sec_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_tlgi_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* employment, firm level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(firmid)
est2vec xtivfrm_tlgi_empl, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_empl)
est2vec xtivfrm_tlgi_empl, r(F p df df_r rank chi2) name(xtfrm_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
est2vec xtivfrm_tlgi_empl, addto(xtivfrm_tlgi_empl) name(xtivfrm_tlgi_empl_now)
est store ivsonly
est2vec xtivfrm_tlgi_empl, raddto(xtivfrm_tlgi_empl) name(xtivfrm_tlgi_empl_now)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_tlgi_empl, addto(xtivfrm_tlgi_empl) name(xtivfrm_tlgi_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivfrm_tlgi_empl, raddto(xtivfrm_tlgi_empl) name(xtivfrm_tlgi_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlgi_empl, raddto(xtivfrm_tlgi_empl) name(xt1frm_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlgi_empl, raddto(xtivfrm_tlgi_empl) name(xt1frm_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_tlgi_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, firm level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(firmid)
est2vec xtivfrm_tlgi_turnov, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_turnov)
est2vec xtivfrm_tlgi_turnov, r(F p df df_r rank chi2) name(xtfrm_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
est2vec xtivfrm_tlgi_turnov, addto(xtivfrm_tlgi_turnov) name(xtivfrm_tlgi_turnov_now)
est store ivsonly
est2vec xtivfrm_tlgi_turnov, raddto(xtivfrm_tlgi_turnov) name(xtivfrm_tlgi_turnov_now)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_tlgi_turnov, addto(xtivfrm_tlgi_turnov) name(xtivfrm_tlgi_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivfrm_tlgi_turnov, raddto(xtivfrm_tlgi_turnov) name(xtivfrm_tlgi_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlgi_turnov, raddto(xtivfrm_tlgi_turnov) name(xt1frm_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlgi_turnov, raddto(xtivfrm_tlgi_turnov) name(xt1frm_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_tlgi_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


/* LEVEL REGRESSIONS, NOT CONDITIONAL ON PAST */

* employment, OLS and 2SLS

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU
est2vec iv_tlg_empl, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_empl)
est2vec iv_tlg_empl, r(F p df df_r rank chi2) name(ols_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlg_empl, addto(iv_tlg_empl) name(iv_tlg_empl_now)
est store ivsonly
est2vec iv_tlg_empl, raddto(iv_tlg_empl) name(iv_tlg_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlg_empl, addto(iv_tlg_empl) name(iv_tlg_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlg_empl, raddto(iv_tlg_empl) name(iv_tlg_empl)

reg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*
est2vec iv_tlg_empl, addto(iv_tlg_empl) name(xtyr_empl)
est2vec iv_tlg_empl, raddto(iv_tlg_empl) name(xtyr_empl)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlg_empl, addto(iv_tlg_empl) name(xtivyr_empl_now)
est store ivsonly
est2vec iv_tlg_empl, raddto(iv_tlg_empl) name(xtivyr_empl_now)

ivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_tlg_empl, addto(iv_tlg_empl) name(xtivyr_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlg_empl, raddto(iv_tlg_empl) name(xtivyr_empl)

foreach reg in $regagg {
  reg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec iv_tlg_empl, raddto(iv_tlg_empl) name(iv1_empl_`reg')
  reg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec iv_tlg_empl, raddto(iv_tlg_empl) name(iv1_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_iv_tlg_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, OLS and 2SLS

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU
est2vec iv_tlg_turnov, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_turnov)
est2vec iv_tlg_turnov, r(F p df df_r rank chi2) name(ols_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlg_turnov, addto(iv_tlg_turnov) name(iv_tlg_turnov_now)
est store ivsonly
est2vec iv_tlg_turnov, raddto(iv_tlg_turnov) name(iv_tlg_turnov_now)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
est2vec iv_tlg_turnov, addto(iv_tlg_turnov) name(iv_tlg_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlg_turnov, raddto(iv_tlg_turnov) name(iv_tlg_turnov)

reg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*
est2vec iv_tlg_turnov, addto(iv_tlg_turnov) name(xtyr_turnov)
est2vec iv_tlg_turnov, raddto(iv_tlg_turnov) name(xtyr_turnov)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU)
est2vec iv_tlg_turnov, addto(iv_tlg_turnov) name(xtivyr_turnov_now)
est store ivsonly
est2vec iv_tlg_turnov, raddto(iv_tlg_turnov) name(xtivyr_turnov_now)

ivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec iv_tlg_turnov, addto(iv_tlg_turnov) name(xtivyr_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec iv_tlg_turnov, raddto(iv_tlg_turnov) name(xtivyr_turnov)

foreach reg in $regagg {
  reg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec iv_tlg_turnov, raddto(iv_tlg_turnov) name(iv1_turnov_`reg')
  reg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec iv_tlg_turnov, raddto(iv_tlg_turnov) name(iv1_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_iv_tlg_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* employment, sector (sec1_bem) level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_tlg_empl, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_empl)
est2vec xtivsec_tlg_empl, r(F p df df_r rank chi2) name(xtsec_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
est2vec xtivsec_tlg_empl, addto(xtivsec_tlg_empl) name(xtivsec_tlg_empl_now)
est store ivsonly
est2vec xtivsec_tlg_empl, raddto(xtivsec_tlg_empl) name(xtivsec_tlg_emp_now)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_tlg_empl, addto(xtivsec_tlg_empl) name(xtivsec_tlg_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivsec_tlg_empl, raddto(xtivsec_tlg_empl) name(xtivsec_tlg_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlg_empl, raddto(xtivsec_tlg_empl) name(xt1sec_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlg_empl, raddto(xtivsec_tlg_empl) name(xt1sec_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_tlg_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, sector (sec1_bem) level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(sec1_bem)
est2vec xtivsec_tlg_turnov, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtsec_turnov)
est2vec xtivsec_tlg_turnov, r(F p df df_r rank chi2) name(xtsec_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(sec1_bem)
est2vec xtivsec_tlg_turnov, addto(xtivsec_tlg_turnov) name(xtivsec_tlg_turnov_now)
est store ivsonly
est2vec xtivsec_tlg_turnov, raddto(xtivsec_tlg_turnov) name(xtivsec_tlg_turnov_now)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(sec1_bem)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivsec_tlg_turnov, addto(xtivsec_tlg_turnov) name(xtivsec_tlg_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivsec_tlg_turnov, raddto(xtivsec_tlg_turnov) name(xtivsec_tlg_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlg_turnov, raddto(xtivsec_tlg_turnov) name(xt1sec_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(sec1_bem)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivsec_tlg_turnov, raddto(xtivsec_tlg_turnov) name(xt1sec_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivsec_tlg_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* employment, firm level

xtreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU indyr*, fe i(firmid)
est2vec xtivfrm_tlg_empl, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_empl)
est2vec xtivfrm_tlg_empl, r(F p df df_r rank chi2) name(xtfrm_empl)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
est2vec xtivfrm_tlg_empl, addto(xtivfrm_tlg_empl) name(xtivfrm_tlg_empl_now)
est store ivsonly
est2vec xtivfrm_tlg_empl, raddto(xtivfrm_tlg_empl) name(xtivfrm_tlg_empl_now)

xtivreg employmt_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_tlg_empl, addto(xtivfrm_tlg_empl) name(xtivfrm_tlg_empl)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivfrm_tlg_empl, raddto(xtivfrm_tlg_empl) name(xtivfrm_tlg_empl)

foreach reg in $regagg {
  xtreg employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlg_empl, raddto(xtivfrm_tlg_empl) name(xt1frm_empl_`reg')
  xtreg cmpt_employmt_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlg_empl, raddto(xtivfrm_tlg_empl) name(xt1frm_cmpt_empl_`reg')
  }

summ2tex employmt_par equity_par liab_par prft_eqty_par ind_exp_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_tlg_empl) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* turnover, firm level

xtreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU indyr*, fe i(firmid)
est2vec xtivfrm_tlg_turnov, vars(employmt_CEE employmt_DEV employmt_OIN employmt_WEU equity_par liab_par prft_eqty_par ind_exp_par cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr1 indyr2 indyr3 indyr4 indyr5 indyr6) e(N ll chi2 p df_m r2 r2_p rc ic) name(xtfrm_turnov)
est2vec xtivfrm_tlg_turnov, r(F p df df_r rank chi2) name(xtfrm_turnov)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU), fe i(firmid)
est2vec xtivfrm_tlg_turnov, addto(xtivfrm_tlg_turnov) name(xtivfrm_tlg_turnov_now)
est store ivsonly
est2vec xtivfrm_tlg_turnov, raddto(xtivfrm_tlg_turnov) name(xtivfrm_tlg_turnov_now)

xtivreg turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* (turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU = vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU), fe i(firmid)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In xtivreg sample"
est2vec xtivfrm_tlg_turnov, addto(xtivfrm_tlg_turnov) name(xtivfrm_tlg_turnov)
est store ivswages
hausman ivswages ivsonly, constant
est2vec xtivfrm_tlg_turnov, raddto(xtivfrm_tlg_turnov) name(xtivfrm_tlg_turnov)

foreach reg in $regagg {
  xtreg turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlg_turnov, raddto(xtivfrm_tlg_turnov) name(xt1frm_turnov_`reg')
  xtreg cmpt_turnover_`reg' vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU turnover_par equity_par liab_par prft_eqty_par ind_exp_par indyr* if indsmpl, fe i(firmid)
  test vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU
  est2vec xtivfrm_tlg_turnov, raddto(xtivfrm_tlg_turnov) name(xt1frm_cmpt_turnov_`reg')
  }

summ2tex turnover_par equity_par liab_par prft_eqty_par ind_exp_par turnover_CEE turnover_DEV turnover_OIN turnover_WEU cmpt_turnover_CEE cmpt_turnover_DEV cmpt_turnover_OIN cmpt_turnover_WEU if indsmpl, c(mean sd N p50) name(summ_xtivfrm_tlg_turnov) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl


* save matrices *

foreach type in b se e r {
  drop _all
  matsave iv_tlgi_4iv_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave iv_tlgi_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave iv_tlgi_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_tlgi_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_tlgi_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_tlgi_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_tlgi_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave iv_tlg_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave iv_tlg_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_tlg_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivsec_tlg_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_tlg_empl_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtivfrm_tlg_turnov_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  }

log close
cd "$root"
