*! version 1.1.3  22oct2008  by Marc Muendler  muendler@ucsd.edu

version 8.2
clear
set memory 400m
set matsize 400
set more off
capture log close

capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf"
capture mkdir "$rootslct/estmat/v6/pt$par-af$aff-$waglvl-cf/cafege"

cd "$rootslct"
log using "logs/xtreg-translog-smpl-pt$par-af$aff-allyrs.log", replace

mat drop _all

adopath + "$root/%stata/ado"


/* region-level IVs and outside margin */
/*-------------------------------------*/

* WTF IVs (one-year lags)
tempfile wtfprox lgwtfprx wtf37
use "$root/trade/wtf-fdiproxies-1989-2000", clear  //  ===in USD billion, US-CPI deflated to base year 1998===
* transform to ===EUR million, deflated to base year 1998===
local idvars "nace11 year"
unab allvars : *
unab relvars : rdl1_*
unab logvars : ln_*
local remvars : list idvars | relvars 
local remvars : list remvars | logvars
local genvars : list allvars - remvars
foreach v of local genvars {
  replace `v' = `v' * 1000 / 1.17499  // from wae 400, bil_jhr 1998, bil_mo 12 in indata/euro-kurse.dta
  }
foreach v of local logvars {
  replace `v' = `v' + log(1000) - log(1.17499)  // from wae 400, bil_jhr 1998, bil_mo 12 in indata/euro-kurse.dta
  }
drop dl1_* rdl1_* ln_*
rename nace11 nace1
preserve
  collapse (mean) vfdi* hfdi* expfdi*, by(year)  // use annual mean of all sectors for sector 37
  gen byte nace1 = 37
  sort nace1 year
  save `wtf37'
restore
append using `wtf37'
sort nace1 year
save `wtfprox'
replace year = year + $yrdiff  // for $yrdiff-year lags (level regressions)
foreach var in vfdi_oecd hfdi_oecd expfdi {
  egen `var'_DEV = rsum(`var'_APC `var'_ODV `var'_RCA)
  egen `var'_WEU = rsum(`var'_EMU `var'_OWE)
  drop `var'_APC `var'_EMU `var'_ODV `var'_OWE `var'_RCA
  }
label var vfdi_oecd_DEV "DEV Exports to OECD (excl. D)"
label var hfdi_oecd_DEV "DEV Imports from OECD (excl. D)"
label var expfdi_DEV "DEV Exp. to neighbors (excl. D)"
label var vfdi_oecd_WEU "WEU Exports to OECD (excl. D)"
label var hfdi_oecd_WEU "WEU Imports from OECD (excl. D)"
label var expfdi_WEU "WEU Exp. to neighbors (excl. D)"
keep nace1 year vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
order nace1 year vfdi_oecd_CEE hfdi_oecd_CEE expfdi_CEE vfdi_oecd_DEV hfdi_oecd_DEV expfdi_DEV vfdi_oecd_OIN hfdi_oecd_OIN expfdi_OIN vfdi_oecd_WEU hfdi_oecd_WEU expfdi_WEU
sort nace1 year
save `lgwtfprx'  // ===in EUR million, deflated to base year 1998===

* German trade at the outside margin
tempfile iso3buba cntrgrpbem lgimpinp
use "$root/conc/fdi-iso-country", clear
rename buba country
keep iso3code country 
sort country
compress
save `iso3buba'
use "$root/conc/cntry2bemgrp", clear
rename bubakey country
sort country
compress
save `cntrgrpbem'
forvalues year = 1997/2002 {
  tempfile impinp`year'
  use "$root/trade/ger-impinp-exp-secbem-ctrygrp-`year'.dta", clear  //  ===in EUR 1,000, D-CPI deflated to base year 2000===
  * transform to ===EUR million, base year 1998===
  replace export = export / ( 1000 * 1.020494 )  // deflator based on cumcpi=cumcpi[_n-1]*(1+dcpi) using outdata/deflators-2005.dta
  replace import = import / ( 1000 * 1.020494 )  // deflator based on cumcpi=cumcpi[_n-1]*(1+dcpi) using outdata/deflators-2005.dta
  replace impinp = impinp / ( 1000 * 1.020494 )  // deflator based on cumcpi=cumcpi[_n-1]*(1+dcpi) using outdata/deflators-2005.dta
  replace buba=11 if buba==23
  drop if buba==950 | buba==958  // 950 `"Schiffs- und Luftfahrzeugbedarf"', 958 `"Nicht ermittelte Lnder und Gebiete"'
  rename buba country
  sort country
  merge country using `cntrgrpbem', nokeep
  qui count if _m~=3
  if `r(N)'>0  STOP  // mismatched country information
  drop _m
  * country group resetting as in %40/sector-country-resetting.do
  gen str3 cntrybemgrp = "CEE" if cntrygrp_bem=="CEE"
  replace  cntrybemgrp = "DEV" if cntrygrp_bem=="APC" | cntrygrp_bem=="ODV" | cntrygrp_bem=="OTR" | cntrygrp_bem=="RCA"
  replace  cntrybemgrp = "OIN" if cntrygrp_bem=="OIN"
  replace  cntrybemgrp = "WEU" if cntrygrp_bem=="EMU" | cntrygrp_bem=="OWE"
  label var cntrybemgrp "Country group"
  collapse (sum) export import impinp, by(nace11_code cntrybemgrp)
  label var export "Exports (Mio EUR, defl. 1998=1)"
  label var import "Imports (Mio EUR, defl. 1998=1)"
  label var impinp "Imp. inputs (Mio EUR, dfl. 1998=1)"
  foreach var in export import impinp {
    rename `var' `var'_
    }
  reshape wide export_ import_ impinp_, i(nace11_code) j(cntrybemgrp) string
  foreach reg of global regagg {
    label var export_`reg' "Exports `reg' (Mio EUR 1998=1)"
    label var import_`reg' "Imports `reg' (Mio EUR 1998=1)"
    label var impinp_`reg' "Imp. inputs `reg' (Mio EUR 1998=1)"
    }
  gen int year = `year' - 1
  label var year "Calendar year"
  sort nace11_code year
  save `impinp`year''
  }
use `impinp1997'
forvalues year = 1998/2002 {
  append using `impinp`year''
  }
rename nace11_code nace1
sort nace1 year
save `lgimpinp'

  
/* employment level data */
/*-----------------------*/

tempfile empldata
use "Xdata/data-parent-hostregion-pt$par-af$aff-allyrs", clear
gen prft_eqty_par = profits_par/equity_par
label var prft_eqty_par "Profits/equity parent"
gen byte ind_exp_par = (exports_par>0 & exports_par~=.)
label var ind_exp_par "Indic.: Exports parent"
gen byte _mcmpvar = .
gen byte _mwage = .
order firmid year ustan nace1 sec1_bem sec1_aggbem employmt_par wb_par turnover_par fixdasst_par assettot_par equity_par liab_par profits_par exports_par prft_eqty_par ind_exp_par
foreach year in 1996 1997 1998 1999 2000 2001 {
  sort firmid year
  merge firmid year using "Xdata/mneid-cafege-competitor-exposure-`year'-$waglvl-pt$par-af$aff", update
  drop if firmid==0
  replace _mcmpvar = _merge if _merge==3 | _merge==4
  drop _merge
  sort firmid year
  merge firmid year using "Xdata/mneid-cafege-wages-`year'-$waglvl", update
  replace _mwage = _merge if _merge==3 | _merge==4
  drop _merge
  }
tab _mcmpvar
qui count if _mcmpvar ~=3 & _mcmpvar ~=4
if `r(N)'>0  STOP  // matching error
drop _mcmpvar
tab _mwage
qui count if _mwage ~=3 & _mwage ~=4 & _mwage~=.
if `r(N)'>0  STOP  // matching error
drop _mwage

sort nace1 year
merge nace1 year using `lgwtfprx', nokeep
qui count if _merge ~=3
if `r(N)'>0  STOP  // matching error
drop _m

sort nace1 year
merge nace1 year using `lgimpinp', nokeep
qui count if _merge ~=3
if `r(N)'>0  STOP  // matching error
drop _m

table nace1 year, c(mean employmt_par)
table nace1 year, c(mean employmt_CEE)
table nace1 year, c(mean cmpt_employmt_CEE)
table nace1 year, c(mean w_CEE)
drop if nace1==37  // remove sector with scattered observations

sort firmid year
save `empldata'


/* link to translog (Heckman correction) data */
/*--------------------------------------------*/
* code similar to translog-selct-2stp-cf.do

foreach tlogyear in 1998 1999 2000 2001 {

tempfile mnes`tlogyear'
local tlogyr = substr("`tlogyear'",3,2)
local selyear = `tlogyear' - ${yrdiff}
local selyr = substr("`selyear'",3,2)

tempfile popinfo
use if year==`tlogyear' using "$rootslct/Xdata/pop-reg-nonattrition-pt$par-af$aff-allyrs", clear
keep mneid iCEnow iDEnow iOInow iWEnow iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg
sort mneid
compress
save `popinfo'

* w_othr
use if year==`tlogyear' using `empldata', clear
drop year profits_par wb_CEE wb_DEV wb_OIN wb_WEU fixdasst_* assettot_* cmpt_wb_* cmpt_fixdasst_* numaffil_* w_CEE w_DEV w_OIN w_WEU
rename firmid mneid
merge mneid using "$rootslct/Xdata/mneid-outwfdi-ustan-`selyear'-costothr-$waglvl-pt$par-af$aff"
drop s_othr_* k_othr_* t_othr_* l_othr_* wb_othr_*
tab _merge  // note: _m==2 b/c universe firms in mneid-outwfdi-ustan but only sample firms in `empldata'
foreach reg in $regagg {
  qui gen _avg_w_`reg' = w_othr_`reg' if mneid==0 /* market average (mneid==0 in using data) */
  qui egen _rpl_w_`reg' = max(_avg_w_`reg')
  qui replace w_othr_`reg' = _rpl_w_`reg' if w_othr_`reg'==. /* replace missing competitor info with market average (mneid==0 in using data) */
  drop _avg_w_`reg' _rpl_w_`reg'
  }
drop if _m==2
drop _merge

* past presence indicators
sort mneid
merge mneid using `popinfo', nokeep
tab _m
drop _m

sort mneid
gen year = `tlogyear'
label var year "Year (production, selection: -$yrdiff)"

order mneid year
save `mnes`tlogyear''

}  /* close `tlogyear' loop */

use `mnes1998'
forvalues tlogyear = 1999/2001 {
  append using `mnes`tlogyear''
  }
sort mneid year
compress

* variable resetting
rename mneid firmid
tabulate year, generate(indyr)
drop indyr1  // omitted year
tsset, clear

* LOG TRANSFORMATION

unab outmarg : export_??? import_??? impinp_???
unab ivs :  vfdi_oecd_??? hfdi_oecd_??? expfdi_???
foreach var in employmt_par equity_par liab_par w_HOM `outmarg' employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU `ivs' {
  local lbl : variable label `var'
  local lbl "ln `lbl'"
  gen ln_`var' = log(`var') if `var'>0 & `var'~=.
  replace ln_`var' = 0 if `var'==0 & `var'~=.
  label var ln_`var' "`lbl'"
  }

* INTERACTED INSTRUMENTS

gen ia_vCEE = iCE2yrlg * vfdi_oecd_CEE
gen ia_vDEV = iDE2yrlg * vfdi_oecd_DEV
gen ia_vOIN = iOI2yrlg * vfdi_oecd_OIN
gen ia_vWEU = iWE2yrlg * vfdi_oecd_WEU
label var ia_vCEE "iCE2yrlg * vfdi_oecd_CEE"
label var ia_vDEV "iDE2yrlg * vfdi_oecd_DEV"
label var ia_vOIN "iOI2yrlg * vfdi_oecd_OIN"
label var ia_vWEU "iWE2yrlg * vfdi_oecd_WEU"

gen ia_wCEE = iCE2yrlg * w_othr_CEE
gen ia_wDEV = iDE2yrlg * w_othr_DEV
gen ia_wOIN = iOI2yrlg * w_othr_OIN
gen ia_wWEU = iWE2yrlg * w_othr_WEU
label var ia_wCEE "iCE2yrlg * w_othr_CEE"
label var ia_wDEV "iDE2yrlg * w_othr_DEV"
label var ia_wOIN "iOI2yrlg * w_othr_OIN"
label var ia_wWEU "iWE2yrlg * w_othr_WEU"


/* LEVEL REGRESSIONS */
desc

unab vars : employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr*

reg employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr*
est2vec xtreg, vars(`vars') e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_empl)
est2vec xtreg, r(F p df df_r rank chi2) name(ols_empl)

ivreg employmt_par w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec xtreg, addto(xtreg) name(iv_empl)
est store ivsonly
est2vec xtreg, raddto(xtreg) name(iv_empl)

xtreg employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr*, fe i(firmid)
est2vec xtreg, addto(xtreg) name(xt_empl)
est2vec xtreg, raddto(xtreg) name(xt_empl)

xtivreg employmt_par w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU), fe i(firmid)
gen byte indsmplxt = e(sample)
label var indsmplxt "Indic.: In xt-IV sample"
est2vec xtreg, addto(xtreg) name(xtiv_empl)
est store ivsonly
est2vec xtreg, raddto(xtreg) name(xtiv_empl)

foreach reg in $regagg {
  local r2dgt = substr("`reg'",1,2)
  reg employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* if indsmpl
  est2vec xtreg, addto(xtreg) name(iv1_empl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtreg, raddto(xtreg) name(iv1_empl_`reg')
  xtreg employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* if indsmplxt, fe i(firmid)
  est2vec xtreg, addto(xtreg) name(xtiv1_empl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtreg, raddto(xtreg) name(xtiv1_empl_`reg')
  }

summ2tex employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU indyr* if indsmpl, c(mean sd N p50) name(summ_xtreg) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl indsmplxt


/* LOG LEVEL REGRESSIONS */

unab vars: ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr*

reg ln_employmt_par ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr*
est2vec xtregln, vars(`vars') e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_lnempl)
est2vec xtregln, r(F p df df_r rank chi2) name(ols_lnempl)

ivreg ln_employmt_par ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr* (ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec xtregln, addto(xtregln) name(iv_lnempl)
est store ivsonly
est2vec xtregln, raddto(xtregln) name(iv_lnempl)

xtreg ln_employmt_par ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr*, fe i(firmid)
est2vec xtregln, addto(xtregln) name(xt_lnempl)
est2vec xtregln, raddto(xtregln) name(xt_lnempl)

xtivreg ln_employmt_par ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr* (ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU), fe i(firmid)
gen byte indsmplxt = e(sample)
label var indsmplxt "Indic.: In xt-IV sample"
est2vec xtregln, addto(xtregln) name(xtiv_lnempl)
est store ivsonly
est2vec xtregln, raddto(xtregln) name(xtiv_lnempl)

foreach reg in $regagg {
  local r2dgt = substr("`reg'",1,2)
  reg ln_employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr* if indsmpl
  est2vec xtregln, addto(xtregln) name(iv1_lnempl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtregln, raddto(xtregln) name(iv1_lnempl_`reg')
  xtreg ln_employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr* if indsmplxt, fe i(firmid)
  est2vec xtregln, addto(xtregln) name(xtiv1_lnempl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtregln, raddto(xtregln) name(xtiv1_lnempl_`reg')
  }

summ2tex ln_employmt_par ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU indyr* if indsmpl, c(mean sd N p50) name(summ_xtregln) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl indsmplxt


/* LEVEL REGRESSIONS, COMPETITOR EFFECTS */

unab vars : employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr*

reg employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr*
est2vec xtregcmpt, vars(`vars') e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_empl)
est2vec xtregcmpt, r(F p df df_r rank chi2) name(ols_empl)

ivreg employmt_par w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec xtregcmpt, addto(xtregcmpt) name(iv_empl)
est store ivsonly
est2vec xtregcmpt, raddto(xtregcmpt) name(iv_empl)

xtreg employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr*, fe i(firmid)
est2vec xtregcmpt, addto(xtregcmpt) name(xt_empl)
est2vec xtregcmpt, raddto(xtregcmpt) name(xt_empl)

xtivreg employmt_par w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* (employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU), fe i(firmid)
gen byte indsmplxt = e(sample)
label var indsmplxt "Indic.: In xt-IV sample"
est2vec xtregcmpt, addto(xtregcmpt) name(xtiv_empl)
est store ivsonly
est2vec xtregcmpt, raddto(xtregcmpt) name(xtiv_empl)

foreach reg in $regagg {
  local r2dgt = substr("`reg'",1,2)
  reg employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* if indsmpl
  est2vec xtregcmpt, addto(xtregcmpt) name(iv1_empl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtregcmpt, raddto(xtregcmpt) name(iv1_empl_`reg')
  xtreg employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? indyr* if indsmplxt, fe i(firmid)
  est2vec xtregcmpt, addto(xtregcmpt) name(xtiv1_empl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtregcmpt, raddto(xtregcmpt) name(xtiv1_empl_`reg')
  }

summ2tex employmt_par employmt_CEE employmt_DEV employmt_OIN employmt_WEU cmpt_employmt_CEE cmpt_employmt_DEV cmpt_employmt_OIN cmpt_employmt_WEU w_HOM equity_par liab_par prft_eqty_par ind_exp_par export_??? import_??? impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU indyr* if indsmpl, c(mean sd N p50) name(summ_xtregcmpt) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl indsmplxt


/* LOG LEVEL REGRESSIONS, COMPETITOR EFFECTS */

unab vars : ln_employmt_par ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_cmpt_employmt_CEE ln_cmpt_employmt_DEV ln_cmpt_employmt_OIN ln_cmpt_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU iCE2yrlg iDE2yrlg iOI2yrlg iWE2yrlg indyr*

reg ln_employmt_par ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_cmpt_employmt_CEE ln_cmpt_employmt_DEV ln_cmpt_employmt_OIN ln_cmpt_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr*
est2vec xtregcmptln, vars(`vars') e(N ll chi2 p df_m r2 r2_p rc ic) name(ols_lnempl)
est2vec xtregcmptln, r(F p df df_r rank chi2) name(ols_lnempl)

ivreg ln_employmt_par ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr* (ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_cmpt_employmt_CEE ln_cmpt_employmt_DEV ln_cmpt_employmt_OIN ln_cmpt_employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU)
gen byte indsmpl = e(sample)
label var indsmpl "Indic.: In IV sample"
est2vec xtregcmptln, addto(xtregcmptln) name(iv_lnempl)
est store ivsonly
est2vec xtregcmptln, raddto(xtregcmptln) name(iv_lnempl)

xtreg ln_employmt_par ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_cmpt_employmt_CEE ln_cmpt_employmt_DEV ln_cmpt_employmt_OIN ln_cmpt_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr*, fe i(firmid)
est2vec xtregcmptln, addto(xtregcmptln) name(xt_lnempl)
est2vec xtregcmptln, raddto(xtregcmptln) name(xt_lnempl)

xtivreg ln_employmt_par ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? (ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_cmpt_employmt_CEE ln_cmpt_employmt_DEV ln_cmpt_employmt_OIN ln_cmpt_employmt_WEU = w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU) indyr*, fe i(firmid)
gen byte indsmplxt = e(sample)
label var indsmplxt "Indic.: In xt-IV sample"
est2vec xtregcmptln, addto(xtregcmptln) name(xtiv_lnempl)
est store ivsonly
est2vec xtregcmptln, raddto(xtregcmptln) name(xtiv_lnempl)

foreach reg in $regagg {
  local r2dgt = substr("`reg'",1,2)
  reg ln_employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr* if indsmpl
  est2vec xtregcmptln, addto(xtregcmptln) name(iv1_lnempl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtregcmptln, raddto(xtregcmptln) name(iv1_lnempl_`reg')
  xtreg ln_employmt_`reg' w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? indyr* if indsmplxt, fe i(firmid)
  est2vec xtregcmptln, addto(xtregcmptln) name(xtiv1_lnempl_`reg')
  test w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU
  est2vec xtregcmptln, raddto(xtregcmptln) name(xtiv1_lnempl_`reg')
  }

summ2tex ln_employmt_par ln_employmt_CEE ln_employmt_DEV ln_employmt_OIN ln_employmt_WEU ln_cmpt_employmt_CEE ln_cmpt_employmt_DEV ln_cmpt_employmt_OIN ln_cmpt_employmt_WEU ln_w_HOM ln_equity_par ln_liab_par prft_eqty_par ind_exp_par ln_export_??? ln_import_??? ln_impinp_??? w_othr_CEE w_othr_DEV w_othr_OIN w_othr_WEU ia_wCEE ia_wDEV ia_wOIN ia_wWEU indyr* if indsmpl, c(mean sd N p50) name(summ_xtregcmptln) p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) replace detail
drop indsmpl indsmplxt


/* SAVE MATRICES */

foreach type in b se e r {
  drop _all
  matsave xtreg_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtregln_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtregcmpt_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  drop _all
  matsave xtregcmptln_`type', p(estmat/v6/pt$par-af$aff-$waglvl-cf/cafege) t(double) replace
  }

log close
cd "$root"
